# ultracart_api

UltracartClient - the Ruby gem for the UltraCart Rest API V2

UltraCart REST API Version 2

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Package version: 3.6.11
- Build package: io.swagger.codegen.languages.RubyClientCodegen
For more information, please visit [http://www.ultracart.com](http://www.ultracart.com)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build ultracart_api.gemspec
```

Then either install the gem locally:

```shell
gem install ./ultracart_api-3.6.11.gem
```
(for development, run `gem install --dev ./ultracart_api-3.6.11.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'ultracart_api', '~> 3.6.11'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/UltraCart/rest_api_v2_sdk_ruby, then add the following in the Gemfile:

    gem 'ultracart_api', :git => 'https://github.com/UltraCart/rest_api_v2_sdk_ruby.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'ultracart_api'


# Create a Simple Key: https://ultracart.atlassian.net/wiki/spaces/ucdoc/pages/38688545/API+Simple+Key
simple_key = '109ee846ee69f50177018ab12f008a00748a25aa28dbdc0177018ab12f008a00'
api_instance = UltracartClient::AffiliateApi.new_using_api_key(simple_key, false, false)

api_instance = UltracartClient::AffiliateApi.new

click_query = UltracartClient::AffiliateClickQuery.new # AffiliateClickQuery | Click query

opts = { 
  _limit: 10000, # Integer | The maximum number of records to return on this one API call. (Maximum 10000)
  _offset: 0, # Integer | Pagination of the record set.  Offset is a zero based index.
  _expand: '_expand_example' # String | The object expansion to perform on the result.  Only option is link.
}

begin
  #Retrieve clicks
  result = api_instance.get_clicks_by_query(click_query, opts)
  p result
rescue UltracartClient::ApiError => e
  puts "Exception when calling AffiliateApi->get_clicks_by_query: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://secure.ultracart.com/rest/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*UltracartClient::AffiliateApi* | [**get_clicks_by_query**](docs/AffiliateApi.md#get_clicks_by_query) | **POST** /affiliate/clicks/query | Retrieve clicks
*UltracartClient::AffiliateApi* | [**get_ledgers_by_query**](docs/AffiliateApi.md#get_ledgers_by_query) | **POST** /affiliate/ledgers/query | Retrieve ledger entries
*UltracartClient::AutoOrderApi* | [**get_auto_order**](docs/AutoOrderApi.md#get_auto_order) | **GET** /auto_order/auto_orders/{auto_order_oid} | Retrieve an auto order by oid
*UltracartClient::AutoOrderApi* | [**get_auto_order_by_code**](docs/AutoOrderApi.md#get_auto_order_by_code) | **GET** /auto_order/auto_orders/code/{auto_order_code} | Retrieve an auto order by code
*UltracartClient::AutoOrderApi* | [**get_auto_order_by_reference_order_id**](docs/AutoOrderApi.md#get_auto_order_by_reference_order_id) | **GET** /auto_order/auto_orders/reference_order_id/{reference_order_id} | Retrieve an auto order by order id
*UltracartClient::AutoOrderApi* | [**get_auto_orders**](docs/AutoOrderApi.md#get_auto_orders) | **GET** /auto_order/auto_orders | Retrieve auto orders
*UltracartClient::AutoOrderApi* | [**get_auto_orders_batch**](docs/AutoOrderApi.md#get_auto_orders_batch) | **POST** /auto_order/auto_orders/batch | Retrieve auto order batch
*UltracartClient::AutoOrderApi* | [**get_auto_orders_by_query**](docs/AutoOrderApi.md#get_auto_orders_by_query) | **POST** /auto_order/auto_orders/query | Retrieve auto orders by query
*UltracartClient::AutoOrderApi* | [**update_auto_order**](docs/AutoOrderApi.md#update_auto_order) | **PUT** /auto_order/auto_orders/{auto_order_oid} | Update an auto order
*UltracartClient::AutoOrderApi* | [**update_auto_orders_batch**](docs/AutoOrderApi.md#update_auto_orders_batch) | **PUT** /auto_order/auto_orders/batch | Update multiple auto orders
*UltracartClient::ChargebackApi* | [**delete_chargeback**](docs/ChargebackApi.md#delete_chargeback) | **DELETE** /chargeback/chargebacks/{chargeback_dispute_oid} | Delete a chargeback
*UltracartClient::ChargebackApi* | [**get_chargeback_dispute**](docs/ChargebackApi.md#get_chargeback_dispute) | **GET** /chargeback/chargebacks/{chargeback_dispute_oid} | Retrieve a chargeback
*UltracartClient::ChargebackApi* | [**get_chargeback_disputes**](docs/ChargebackApi.md#get_chargeback_disputes) | **GET** /chargeback/chargebacks | Retrieve chargebacks
*UltracartClient::ChargebackApi* | [**insert_chargeback**](docs/ChargebackApi.md#insert_chargeback) | **POST** /chargeback/chargebacks | Insert a chargeback
*UltracartClient::ChargebackApi* | [**update_chargeback**](docs/ChargebackApi.md#update_chargeback) | **PUT** /chargeback/chargebacks/{chargeback_dispute_oid} | Update a chargeback
*UltracartClient::CheckoutApi* | [**city_state**](docs/CheckoutApi.md#city_state) | **POST** /checkout/city_state | City/State for Zip
*UltracartClient::CheckoutApi* | [**finalize_order**](docs/CheckoutApi.md#finalize_order) | **POST** /checkout/cart/finalizeOrder | Finalize Order
*UltracartClient::CheckoutApi* | [**get_affirm_checkout**](docs/CheckoutApi.md#get_affirm_checkout) | **GET** /checkout/cart/{cart_id}/affirmCheckout | Get affirm checkout (by cart id)
*UltracartClient::CheckoutApi* | [**get_allowed_countries**](docs/CheckoutApi.md#get_allowed_countries) | **POST** /checkout/allowedCountries | Allowed countries
*UltracartClient::CheckoutApi* | [**get_cart**](docs/CheckoutApi.md#get_cart) | **GET** /checkout/cart | Get cart
*UltracartClient::CheckoutApi* | [**get_cart_by_cart_id**](docs/CheckoutApi.md#get_cart_by_cart_id) | **GET** /checkout/cart/{cart_id} | Get cart (by cart id)
*UltracartClient::CheckoutApi* | [**get_cart_by_return_code**](docs/CheckoutApi.md#get_cart_by_return_code) | **GET** /checkout/return/{return_code} | Get cart (by return code)
*UltracartClient::CheckoutApi* | [**get_cart_by_return_token**](docs/CheckoutApi.md#get_cart_by_return_token) | **GET** /checkout/return_token | Get cart (by return token)
*UltracartClient::CheckoutApi* | [**get_state_provinces_for_country**](docs/CheckoutApi.md#get_state_provinces_for_country) | **POST** /checkout/stateProvincesForCountry/{country_code} | Get state/province list for a country code
*UltracartClient::CheckoutApi* | [**handoff_cart**](docs/CheckoutApi.md#handoff_cart) | **POST** /checkout/cart/handoff | Handoff cart
*UltracartClient::CheckoutApi* | [**login**](docs/CheckoutApi.md#login) | **POST** /checkout/cart/profile/login | Profile login
*UltracartClient::CheckoutApi* | [**logout**](docs/CheckoutApi.md#logout) | **POST** /checkout/cart/profile/logout | Profile logout
*UltracartClient::CheckoutApi* | [**register**](docs/CheckoutApi.md#register) | **POST** /checkout/cart/profile/register | Profile registration
*UltracartClient::CheckoutApi* | [**register_affiliate_click**](docs/CheckoutApi.md#register_affiliate_click) | **POST** /checkout/affiliateClick/register | Register affiliate click
*UltracartClient::CheckoutApi* | [**related_items_for_cart**](docs/CheckoutApi.md#related_items_for_cart) | **POST** /checkout/related_items | Related items
*UltracartClient::CheckoutApi* | [**related_items_for_item**](docs/CheckoutApi.md#related_items_for_item) | **POST** /checkout/relatedItems/{item_id} | Related items (specific item)
*UltracartClient::CheckoutApi* | [**setup_browser_key**](docs/CheckoutApi.md#setup_browser_key) | **PUT** /checkout/browser_key | Setup Browser Application
*UltracartClient::CheckoutApi* | [**update_cart**](docs/CheckoutApi.md#update_cart) | **PUT** /checkout/cart | Update cart
*UltracartClient::CheckoutApi* | [**validate_cart**](docs/CheckoutApi.md#validate_cart) | **POST** /checkout/cart/validate | Validate
*UltracartClient::ConfigurationApi* | [**delay_auto_orders**](docs/ConfigurationApi.md#delay_auto_orders) | **POST** /configuration/checkout/payments/rtg/{rtg_oid}/delayAutoOrders | Delay auto order processing for a day for this rotating transaction gateway
*UltracartClient::ConfigurationApi* | [**delete_rotating_transaction_gateway**](docs/ConfigurationApi.md#delete_rotating_transaction_gateway) | **DELETE** /configuration/checkout/payments/rtg/{rtg_oid} | Delete a rotating transaction gateway
*UltracartClient::ConfigurationApi* | [**get_payments_configuration**](docs/ConfigurationApi.md#get_payments_configuration) | **GET** /configuration/checkout/payments | Retrieve payments configuration
*UltracartClient::ConfigurationApi* | [**get_payments_rotating_gateway**](docs/ConfigurationApi.md#get_payments_rotating_gateway) | **GET** /configuration/checkout/payments/rtg/{rtg_oid} | Retrieve a rotating transaction gateway
*UltracartClient::ConfigurationApi* | [**get_payments_rotating_gateway_by_code**](docs/ConfigurationApi.md#get_payments_rotating_gateway_by_code) | **GET** /configuration/checkout/payments/rtg/byCode/{code} | Retrieve a rotating transaction gateway by code
*UltracartClient::ConfigurationApi* | [**get_payments_rotating_transaction_gateways**](docs/ConfigurationApi.md#get_payments_rotating_transaction_gateways) | **GET** /configuration/checkout/payments/rtg | Retrieve a list of rotating transaction gateways
*UltracartClient::ConfigurationApi* | [**get_payments_rtg_summaries**](docs/ConfigurationApi.md#get_payments_rtg_summaries) | **GET** /configuration/checkout/payments/rtg/summaries | Retrieve a summary of rotating transaction gateways
*UltracartClient::ConfigurationApi* | [**get_payments_transaction_gateways**](docs/ConfigurationApi.md#get_payments_transaction_gateways) | **GET** /configuration/checkout/payments/tg | Retrieve a list of transaction gateways
*UltracartClient::ConfigurationApi* | [**insert_rotating_transaction_gateway**](docs/ConfigurationApi.md#insert_rotating_transaction_gateway) | **POST** /configuration/checkout/payments/rtg/ | Insert a rotating transaction gateway
*UltracartClient::ConfigurationApi* | [**migrate_to_rotating_transaction_gateway**](docs/ConfigurationApi.md#migrate_to_rotating_transaction_gateway) | **POST** /configuration/checkout/payments/tg/migrateToRtgWithCodeOf/{code} | Migrate a normal transaction gateway to a rotating transaction gateway
*UltracartClient::ConfigurationApi* | [**stripe_connect**](docs/ConfigurationApi.md#stripe_connect) | **POST** /configuration/checkout/payments/rtg/{rtg_oid}/stripeConnect | Begin the processing of connecting with Stripe
*UltracartClient::ConfigurationApi* | [**update_payments_configuration**](docs/ConfigurationApi.md#update_payments_configuration) | **PUT** /configuration/checkout/payments | Updates payments configuration
*UltracartClient::ConfigurationApi* | [**update_payments_transaction_gateway**](docs/ConfigurationApi.md#update_payments_transaction_gateway) | **PUT** /configuration/checkout/payments/tg | Updates payments transaction gateway
*UltracartClient::ConfigurationApi* | [**update_rotating_transaction_gateway**](docs/ConfigurationApi.md#update_rotating_transaction_gateway) | **PUT** /configuration/checkout/payments/rtg/{rtg_oid} | Update a rotating transaction gateway
*UltracartClient::ConfigurationApi* | [**wepay_enroll**](docs/ConfigurationApi.md#wepay_enroll) | **PUT** /configuration/checkout/wepayEnroll | Enroll with WePay
*UltracartClient::CouponApi* | [**delete_coupon**](docs/CouponApi.md#delete_coupon) | **DELETE** /coupon/coupons/{coupon_oid} | Delete a coupon
*UltracartClient::CouponApi* | [**delete_coupons_by_code**](docs/CouponApi.md#delete_coupons_by_code) | **DELETE** /coupon/coupons/by_code | Deletes multiple coupons
*UltracartClient::CouponApi* | [**delete_coupons_by_oid**](docs/CouponApi.md#delete_coupons_by_oid) | **DELETE** /coupon/coupons/by_oid | Deletes multiple coupons
*UltracartClient::CouponApi* | [**does_coupon_code_exist**](docs/CouponApi.md#does_coupon_code_exist) | **GET** /coupon/coupons/merchant_code/{merchant_code}/exists | Determines if a coupon merchant code already exists
*UltracartClient::CouponApi* | [**generate_coupon_codes**](docs/CouponApi.md#generate_coupon_codes) | **POST** /coupon/coupons/{coupon_oid}/generate_codes | Generates one time codes for a coupon
*UltracartClient::CouponApi* | [**generate_one_time_codes_by_merchant_code**](docs/CouponApi.md#generate_one_time_codes_by_merchant_code) | **POST** /coupon/coupons/merchant_code/{merchant_code}/generate_codes | Generates one time codes by merchant code
*UltracartClient::CouponApi* | [**get_auto_apply**](docs/CouponApi.md#get_auto_apply) | **GET** /coupon/auto_apply | Retrieve auto apply rules and conditions
*UltracartClient::CouponApi* | [**get_coupon**](docs/CouponApi.md#get_coupon) | **GET** /coupon/coupons/{coupon_oid} | Retrieve a coupon
*UltracartClient::CouponApi* | [**get_coupon_by_merchant_code**](docs/CouponApi.md#get_coupon_by_merchant_code) | **GET** /coupon/coupons/merchant_code/{merchant_code} | Retrieve a coupon by merchant code
*UltracartClient::CouponApi* | [**get_coupons**](docs/CouponApi.md#get_coupons) | **GET** /coupon/coupons | Retrieve coupons
*UltracartClient::CouponApi* | [**get_coupons_by_query**](docs/CouponApi.md#get_coupons_by_query) | **GET** /coupon/coupons/query | Retrieve coupons by query
*UltracartClient::CouponApi* | [**get_editor_values**](docs/CouponApi.md#get_editor_values) | **GET** /coupon/editor_values | Retrieve values needed for a coupon editor
*UltracartClient::CouponApi* | [**insert_coupon**](docs/CouponApi.md#insert_coupon) | **POST** /coupon/coupons | Insert a coupon
*UltracartClient::CouponApi* | [**insert_coupons**](docs/CouponApi.md#insert_coupons) | **POST** /coupon/coupons/batch | Insert multiple coupons
*UltracartClient::CouponApi* | [**search_items**](docs/CouponApi.md#search_items) | **GET** /coupon/searchItems | Searches for items to display within a coupon editor and assign to coupons
*UltracartClient::CouponApi* | [**update_auto_apply**](docs/CouponApi.md#update_auto_apply) | **POST** /coupon/auto_apply | Update auto apply rules and conditions
*UltracartClient::CouponApi* | [**update_coupon**](docs/CouponApi.md#update_coupon) | **PUT** /coupon/coupons/{coupon_oid} | Update a coupon
*UltracartClient::CouponApi* | [**update_coupons**](docs/CouponApi.md#update_coupons) | **PUT** /coupon/coupons/batch | Update multiple coupons
*UltracartClient::CouponApi* | [**upload_coupon_codes**](docs/CouponApi.md#upload_coupon_codes) | **POST** /coupon/coupons/{coupon_oid}/upload_codes | Upload one-time codes for a coupon
*UltracartClient::CustomerApi* | [**delete_customer**](docs/CustomerApi.md#delete_customer) | **DELETE** /customer/customers/{customer_profile_oid} | Delete a customer
*UltracartClient::CustomerApi* | [**get_customer**](docs/CustomerApi.md#get_customer) | **GET** /customer/customers/{customer_profile_oid} | Retrieve a customer
*UltracartClient::CustomerApi* | [**get_customer_by_email**](docs/CustomerApi.md#get_customer_by_email) | **GET** /customer/customers/by_email/{email} | Retrieve a customer by Email
*UltracartClient::CustomerApi* | [**get_customer_editor_values**](docs/CustomerApi.md#get_customer_editor_values) | **GET** /customer/editor_values | Retrieve values needed for a customer profile editor
*UltracartClient::CustomerApi* | [**get_customer_email_lists**](docs/CustomerApi.md#get_customer_email_lists) | **GET** /customer/email_lists | Retrieve all email lists across all storefronts
*UltracartClient::CustomerApi* | [**get_customers**](docs/CustomerApi.md#get_customers) | **GET** /customer/customers | Retrieve customers
*UltracartClient::CustomerApi* | [**get_customers_by_query**](docs/CustomerApi.md#get_customers_by_query) | **POST** /customer/customers/query | Retrieve customers by query
*UltracartClient::CustomerApi* | [**get_customers_for_data_tables**](docs/CustomerApi.md#get_customers_for_data_tables) | **POST** /customer/customers/dataTables | Retrieve customers for DataTables plugin
*UltracartClient::CustomerApi* | [**get_email_verification_token**](docs/CustomerApi.md#get_email_verification_token) | **POST** /customer/customers/email_verify/get_token | Create a token that can be used to verify a customer email address
*UltracartClient::CustomerApi* | [**insert_customer**](docs/CustomerApi.md#insert_customer) | **POST** /customer/customers | Insert a customer
*UltracartClient::CustomerApi* | [**update_customer**](docs/CustomerApi.md#update_customer) | **PUT** /customer/customers/{customer_profile_oid} | Update a customer
*UltracartClient::CustomerApi* | [**update_customer_email_lists**](docs/CustomerApi.md#update_customer_email_lists) | **POST** /customer/customers/{customer_profile_oid}/email_lists | Update email list subscriptions for a customer
*UltracartClient::CustomerApi* | [**validate_email_verification_token**](docs/CustomerApi.md#validate_email_verification_token) | **POST** /customer/customers/email_verify/validate_token | Validate a token that can be used to verify a customer email address
*UltracartClient::FulfillmentApi* | [**acknowledge_orders**](docs/FulfillmentApi.md#acknowledge_orders) | **PUT** /fulfillment/distribution_centers/{distribution_center_code}/acknowledgements | Acknowledge receipt of orders.
*UltracartClient::FulfillmentApi* | [**generate_packing_slip**](docs/FulfillmentApi.md#generate_packing_slip) | **GET** /fulfillment/distribution_centers/{distribution_center_code}/orders/{order_id} | Generate a packing slip for this order for the given distribution center.
*UltracartClient::FulfillmentApi* | [**get_distribution_center_orders**](docs/FulfillmentApi.md#get_distribution_center_orders) | **GET** /fulfillment/distribution_centers/{distribution_center_code}/orders | Retrieve orders queued up for this distribution center.
*UltracartClient::FulfillmentApi* | [**get_distribution_centers**](docs/FulfillmentApi.md#get_distribution_centers) | **GET** /fulfillment/distribution_centers | Retrieve distribution centers
*UltracartClient::FulfillmentApi* | [**ship_orders**](docs/FulfillmentApi.md#ship_orders) | **POST** /fulfillment/distribution_centers/{distribution_center_code}/shipments | Mark orders as shipped
*UltracartClient::FulfillmentApi* | [**update_inventory**](docs/FulfillmentApi.md#update_inventory) | **POST** /fulfillment/distribution_centers/{distribution_center_code}/inventory | Update inventory
*UltracartClient::IntegrationLogApi* | [**get_integration_log**](docs/IntegrationLogApi.md#get_integration_log) | **GET** /integration_log/query/{pk}/{sk} | Retrieve an integration log
*UltracartClient::IntegrationLogApi* | [**get_integration_log_file**](docs/IntegrationLogApi.md#get_integration_log_file) | **GET** /integration_log/query/{pk}/{sk}/{uuid} | Retrieve an integration log file
*UltracartClient::IntegrationLogApi* | [**get_integration_log_summaries_query**](docs/IntegrationLogApi.md#get_integration_log_summaries_query) | **POST** /integration_log/summary/query | Retrieve integration log summaries
*UltracartClient::IntegrationLogApi* | [**get_integration_logs_query**](docs/IntegrationLogApi.md#get_integration_logs_query) | **POST** /integration_log/query | Retrieve integration logs
*UltracartClient::ItemApi* | [**delete_item**](docs/ItemApi.md#delete_item) | **DELETE** /item/items/{merchant_item_oid} | Delete an item
*UltracartClient::ItemApi* | [**get_item**](docs/ItemApi.md#get_item) | **GET** /item/items/{merchant_item_oid} | Retrieve an item
*UltracartClient::ItemApi* | [**get_item_by_merchant_item_id**](docs/ItemApi.md#get_item_by_merchant_item_id) | **GET** /item/items/merchant_item_id/{merchant_item_id} | Retrieve an item by item id
*UltracartClient::ItemApi* | [**get_items**](docs/ItemApi.md#get_items) | **GET** /item/items | Retrieve items
*UltracartClient::ItemApi* | [**get_pricing_tiers**](docs/ItemApi.md#get_pricing_tiers) | **GET** /item/pricing_tiers | Retrieve pricing tiers
*UltracartClient::ItemApi* | [**insert_item**](docs/ItemApi.md#insert_item) | **POST** /item/items | Create an item
*UltracartClient::ItemApi* | [**update_item**](docs/ItemApi.md#update_item) | **PUT** /item/items/{merchant_item_oid} | Update an item
*UltracartClient::ItemApi* | [**update_items**](docs/ItemApi.md#update_items) | **PUT** /item/items/batch | Update multiple items
*UltracartClient::ItemApi* | [**upload_temporary_multimedia**](docs/ItemApi.md#upload_temporary_multimedia) | **POST** /item/temp_multimedia | Upload an image to the temporary multimedia.
*UltracartClient::OauthApi* | [**oauth_access_token**](docs/OauthApi.md#oauth_access_token) | **POST** /oauth/token | Exchange authorization code for access token.
*UltracartClient::OauthApi* | [**oauth_revoke**](docs/OauthApi.md#oauth_revoke) | **POST** /oauth/revoke | Revoke this OAuth application.
*UltracartClient::OrderApi* | [**adjust_order_total**](docs/OrderApi.md#adjust_order_total) | **POST** /order/orders/{order_id}/adjust_order_total/{desired_total} | Adjusts an order total
*UltracartClient::OrderApi* | [**cancel_order**](docs/OrderApi.md#cancel_order) | **POST** /order/orders/{order_id}/cancel | Cancel an order
*UltracartClient::OrderApi* | [**delete_order**](docs/OrderApi.md#delete_order) | **DELETE** /order/orders/{order_id} | Delete an order
*UltracartClient::OrderApi* | [**format**](docs/OrderApi.md#format) | **POST** /order/orders/{order_id}/format | Format order
*UltracartClient::OrderApi* | [**generate_order_token**](docs/OrderApi.md#generate_order_token) | **GET** /order/orders/token/{order_id} | Generate an order token for a given order id
*UltracartClient::OrderApi* | [**generate_packing_slip_all_dc**](docs/OrderApi.md#generate_packing_slip_all_dc) | **GET** /order/orders/{order_id}/packing_slip | Generate a packing slip for this order across all distribution centers.
*UltracartClient::OrderApi* | [**generate_packing_slip_specific_dc**](docs/OrderApi.md#generate_packing_slip_specific_dc) | **GET** /order/orders/{order_id}/packing_slip/{distribution_center_code} | Generate a packing slip for this order for the given distribution center.
*UltracartClient::OrderApi* | [**get_accounts_receivable_retry_config**](docs/OrderApi.md#get_accounts_receivable_retry_config) | **GET** /order/accountsReceivableRetryConfig | Retrieve A/R Retry Configuration
*UltracartClient::OrderApi* | [**get_accounts_receivable_retry_stats**](docs/OrderApi.md#get_accounts_receivable_retry_stats) | **GET** /order/accountsReceivableRetryConfig/stats | Retrieve A/R Retry Statistics
*UltracartClient::OrderApi* | [**get_order**](docs/OrderApi.md#get_order) | **GET** /order/orders/{order_id} | Retrieve an order
*UltracartClient::OrderApi* | [**get_order_by_token**](docs/OrderApi.md#get_order_by_token) | **POST** /order/orders/token | Retrieve an order using a token
*UltracartClient::OrderApi* | [**get_orders**](docs/OrderApi.md#get_orders) | **GET** /order/orders | Retrieve orders
*UltracartClient::OrderApi* | [**get_orders_batch**](docs/OrderApi.md#get_orders_batch) | **POST** /order/orders/batch | Retrieve order batch
*UltracartClient::OrderApi* | [**get_orders_by_query**](docs/OrderApi.md#get_orders_by_query) | **POST** /order/orders/query | Retrieve orders by query
*UltracartClient::OrderApi* | [**insert_order**](docs/OrderApi.md#insert_order) | **POST** /order/orders | Insert an order
*UltracartClient::OrderApi* | [**process_payment**](docs/OrderApi.md#process_payment) | **POST** /order/orders/{order_id}/process_payment | Process payment
*UltracartClient::OrderApi* | [**refund_order**](docs/OrderApi.md#refund_order) | **PUT** /order/orders/{order_id}/refund | Refund an order
*UltracartClient::OrderApi* | [**replacement**](docs/OrderApi.md#replacement) | **POST** /order/orders/{order_id}/replacement | Replacement order
*UltracartClient::OrderApi* | [**resend_receipt**](docs/OrderApi.md#resend_receipt) | **POST** /order/orders/{order_id}/resend_receipt | Resend receipt
*UltracartClient::OrderApi* | [**resend_shipment_confirmation**](docs/OrderApi.md#resend_shipment_confirmation) | **POST** /order/orders/{order_id}/resend_shipment_confirmation | Resend shipment confirmation
*UltracartClient::OrderApi* | [**update_accounts_receivable_retry_config**](docs/OrderApi.md#update_accounts_receivable_retry_config) | **POST** /order/accountsReceivableRetryConfig | Update A/R Retry Configuration
*UltracartClient::OrderApi* | [**update_order**](docs/OrderApi.md#update_order) | **PUT** /order/orders/{order_id} | Update an order
*UltracartClient::SsoApi* | [**get_sso_session_user**](docs/SsoApi.md#get_sso_session_user) | **GET** /sso/session/user | Get single sign on session user
*UltracartClient::SsoApi* | [**sso_authorize**](docs/SsoApi.md#sso_authorize) | **PUT** /sso/authorize | Authorize a single sign on session
*UltracartClient::SsoApi* | [**sso_session_revoke**](docs/SsoApi.md#sso_session_revoke) | **DELETE** /sso/session/revoke | Revoke single sign on session
*UltracartClient::SsoApi* | [**sso_token**](docs/SsoApi.md#sso_token) | **PUT** /sso/token | Exchange a single sign on code for a simple key token
*UltracartClient::StorefrontApi* | [**add_to_library**](docs/StorefrontApi.md#add_to_library) | **POST** /storefront/code_library | Add to library
*UltracartClient::StorefrontApi* | [**apply_to_store_front**](docs/StorefrontApi.md#apply_to_store_front) | **POST** /storefront/code_library/apply | Apply library item to storefront.
*UltracartClient::StorefrontApi* | [**archive_email_list**](docs/StorefrontApi.md#archive_email_list) | **POST** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/archive | Archive email list
*UltracartClient::StorefrontApi* | [**archive_email_segment**](docs/StorefrontApi.md#archive_email_segment) | **POST** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/archive | Archive email segment
*UltracartClient::StorefrontApi* | [**back_populate_email_flow**](docs/StorefrontApi.md#back_populate_email_flow) | **POST** /storefront/{storefront_oid}/email/flows/{email_flow_uuid}/backfill | Back populate email flow
*UltracartClient::StorefrontApi* | [**check_download_email_segment**](docs/StorefrontApi.md#check_download_email_segment) | **POST** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/downloadPrepare/{email_segment_rebuild_uuid} | Check download of email segment
*UltracartClient::StorefrontApi* | [**clone_email_campaign**](docs/StorefrontApi.md#clone_email_campaign) | **POST** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid}/clone | Clone email campaign
*UltracartClient::StorefrontApi* | [**clone_email_flow**](docs/StorefrontApi.md#clone_email_flow) | **POST** /storefront/{storefront_oid}/email/flows/{email_flow_uuid}/clone | Clone email flow
*UltracartClient::StorefrontApi* | [**create_email_sending_domain**](docs/StorefrontApi.md#create_email_sending_domain) | **POST** /storefront/email/sending_domains/{domain}/create | Create email campaign
*UltracartClient::StorefrontApi* | [**delete_email_campaign_folder**](docs/StorefrontApi.md#delete_email_campaign_folder) | **DELETE** /storefront/{storefront_oid}/email/campaign_folders/{email_campaign_folder_uuid} | Delete email campaignFolder
*UltracartClient::StorefrontApi* | [**delete_email_commseq_stat**](docs/StorefrontApi.md#delete_email_commseq_stat) | **DELETE** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/stat | Delete communication sequence stats
*UltracartClient::StorefrontApi* | [**delete_email_email**](docs/StorefrontApi.md#delete_email_email) | **DELETE** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid} | Delete email email
*UltracartClient::StorefrontApi* | [**delete_email_flow_folder**](docs/StorefrontApi.md#delete_email_flow_folder) | **DELETE** /storefront/{storefront_oid}/email/flow_folders/{email_flow_folder_uuid} | Delete email flowFolder
*UltracartClient::StorefrontApi* | [**delete_email_list_customer**](docs/StorefrontApi.md#delete_email_list_customer) | **DELETE** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/customers/{email_customer_uuid} | Delete email list customer
*UltracartClient::StorefrontApi* | [**delete_email_list_segment_folder**](docs/StorefrontApi.md#delete_email_list_segment_folder) | **DELETE** /storefront/{storefront_oid}/email/list_segment_folders/{email_list_segment_folder_uuid} | Delete email ListSegmentFolder
*UltracartClient::StorefrontApi* | [**delete_email_postcard**](docs/StorefrontApi.md#delete_email_postcard) | **DELETE** /storefront/{storefront_oid}/email/postcards/{commseq_postcard_uuid} | Delete email postcard
*UltracartClient::StorefrontApi* | [**delete_email_sending_domain**](docs/StorefrontApi.md#delete_email_sending_domain) | **DELETE** /storefront/email/sending_domains/{domain} | delete email campaign
*UltracartClient::StorefrontApi* | [**delete_experiment**](docs/StorefrontApi.md#delete_experiment) | **DELETE** /storefront/{storefront_oid}/experiments/{storefront_experiment_oid} | Delete experiment
*UltracartClient::StorefrontApi* | [**delete_heatmap**](docs/StorefrontApi.md#delete_heatmap) | **DELETE** /storefront/{storefront_oid}/screen_recordings/heatmap | Delete screen recording heatmap
*UltracartClient::StorefrontApi* | [**delete_library_item**](docs/StorefrontApi.md#delete_library_item) | **DELETE** /storefront/code_library/{library_item_oid} | Delete library item
*UltracartClient::StorefrontApi* | [**delete_library_item_published_versions**](docs/StorefrontApi.md#delete_library_item_published_versions) | **DELETE** /storefront/code_library/{library_item_oid}/published_versions | Delete all published versions for a library item, including anything in review.
*UltracartClient::StorefrontApi* | [**delete_screen_recording_segment**](docs/StorefrontApi.md#delete_screen_recording_segment) | **DELETE** /storefront/{storefront_oid}/screen_recordings/segments/{screen_recording_segment_oid} | Delete screen recording segment
*UltracartClient::StorefrontApi* | [**duplicate_library_item**](docs/StorefrontApi.md#duplicate_library_item) | **POST** /storefront/code_library/{library_item_oid}/duplicate | Duplicate library item.
*UltracartClient::StorefrontApi* | [**favorite_screen_recording**](docs/StorefrontApi.md#favorite_screen_recording) | **POST** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid}/favorite | Update favorite flag on screen recording
*UltracartClient::StorefrontApi* | [**geocode_address**](docs/StorefrontApi.md#geocode_address) | **POST** /storefront/{storefront_oid}/email/geocode | Obtain lat/long for an address
*UltracartClient::StorefrontApi* | [**get_countries**](docs/StorefrontApi.md#get_countries) | **GET** /storefront/{storefront_oid}/email/countries | Get countries
*UltracartClient::StorefrontApi* | [**get_editor_token**](docs/StorefrontApi.md#get_editor_token) | **GET** /storefront/{storefront_oid}/editor_token | Gets editor token
*UltracartClient::StorefrontApi* | [**get_email_base_templates**](docs/StorefrontApi.md#get_email_base_templates) | **GET** /storefront/{storefront_oid}/email/baseTemplates | Get email communication base templates
*UltracartClient::StorefrontApi* | [**get_email_campaign**](docs/StorefrontApi.md#get_email_campaign) | **GET** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid} | Get email campaign
*UltracartClient::StorefrontApi* | [**get_email_campaign_folder**](docs/StorefrontApi.md#get_email_campaign_folder) | **GET** /storefront/{storefront_oid}/email/campaign_folders/{email_campaign_folder_uuid} | Get email campaign folder
*UltracartClient::StorefrontApi* | [**get_email_campaign_folders**](docs/StorefrontApi.md#get_email_campaign_folders) | **GET** /storefront/{storefront_oid}/email/campaign_folders | Get email campaign folders
*UltracartClient::StorefrontApi* | [**get_email_campaign_screenshots**](docs/StorefrontApi.md#get_email_campaign_screenshots) | **GET** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid}/screenshots | Get email campaign screenshots
*UltracartClient::StorefrontApi* | [**get_email_campaigns**](docs/StorefrontApi.md#get_email_campaigns) | **GET** /storefront/{storefront_oid}/email/campaigns | Get email campaigns
*UltracartClient::StorefrontApi* | [**get_email_campaigns_with_stats**](docs/StorefrontApi.md#get_email_campaigns_with_stats) | **GET** /storefront/{storefront_oid}/email/campaignsWithStats/{stat_days} | Get email campaigns with stats
*UltracartClient::StorefrontApi* | [**get_email_commseq**](docs/StorefrontApi.md#get_email_commseq) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid} | Get email commseq
*UltracartClient::StorefrontApi* | [**get_email_commseq_email_stats**](docs/StorefrontApi.md#get_email_commseq_email_stats) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/emailStats | Get email communication sequence emails stats
*UltracartClient::StorefrontApi* | [**get_email_commseq_postcard_stats**](docs/StorefrontApi.md#get_email_commseq_postcard_stats) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/postcardStats | Get email communication sequence postcard stats
*UltracartClient::StorefrontApi* | [**get_email_commseq_stat_overall**](docs/StorefrontApi.md#get_email_commseq_stat_overall) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/stat | Get communication sequence stats overall
*UltracartClient::StorefrontApi* | [**get_email_commseq_step_stats**](docs/StorefrontApi.md#get_email_commseq_step_stats) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/stepStats | Get email communication sequence step stats
*UltracartClient::StorefrontApi* | [**get_email_commseq_step_waiting**](docs/StorefrontApi.md#get_email_commseq_step_waiting) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/waiting | Get email communication sequence customers waiting at each requested step
*UltracartClient::StorefrontApi* | [**get_email_commseq_webhook_editor_values**](docs/StorefrontApi.md#get_email_commseq_webhook_editor_values) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/webhookEditorValues | Get email webhook editor values
*UltracartClient::StorefrontApi* | [**get_email_commseqs**](docs/StorefrontApi.md#get_email_commseqs) | **GET** /storefront/{storefront_oid}/email/commseqs | Get email commseqs
*UltracartClient::StorefrontApi* | [**get_email_customer_editor_url**](docs/StorefrontApi.md#get_email_customer_editor_url) | **GET** /storefront/{storefront_oid}/email/customers/{email_customer_uuid}/editor_url | Get customers editor URL
*UltracartClient::StorefrontApi* | [**get_email_customers**](docs/StorefrontApi.md#get_email_customers) | **GET** /storefront/{storefront_oid}/email/customers | Get email customers
*UltracartClient::StorefrontApi* | [**get_email_dashboard_activity**](docs/StorefrontApi.md#get_email_dashboard_activity) | **GET** /storefront/{storefront_oid}/email/dashboard_activity | Get email dashboard activity
*UltracartClient::StorefrontApi* | [**get_email_dashboard_stats**](docs/StorefrontApi.md#get_email_dashboard_stats) | **GET** /storefront/{storefront_oid}/email/dashboard_stats | Get dashboard stats
*UltracartClient::StorefrontApi* | [**get_email_dispatch_logs**](docs/StorefrontApi.md#get_email_dispatch_logs) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/steps/{commseq_step_uuid}/logs | Get email dispatch logs
*UltracartClient::StorefrontApi* | [**get_email_email**](docs/StorefrontApi.md#get_email_email) | **GET** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid} | Get email email
*UltracartClient::StorefrontApi* | [**get_email_email_clicks**](docs/StorefrontApi.md#get_email_email_clicks) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/steps/{commseq_step_uuid}/emails/{commseq_email_uuid}/clicks | Get email email clicks
*UltracartClient::StorefrontApi* | [**get_email_email_customer_editor_url**](docs/StorefrontApi.md#get_email_email_customer_editor_url) | **GET** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid}/orders/{order_id}/editor_url | Get email order customer editor url
*UltracartClient::StorefrontApi* | [**get_email_email_orders**](docs/StorefrontApi.md#get_email_email_orders) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/steps/{commseq_step_uuid}/emails/{commseq_email_uuid}/orders | Get email email orders
*UltracartClient::StorefrontApi* | [**get_email_emails**](docs/StorefrontApi.md#get_email_emails) | **GET** /storefront/{storefront_oid}/email/emails | Get email emails
*UltracartClient::StorefrontApi* | [**get_email_emails_multiple**](docs/StorefrontApi.md#get_email_emails_multiple) | **POST** /storefront/{storefront_oid}/email/emails/multiple | Get email emails multiple
*UltracartClient::StorefrontApi* | [**get_email_flow**](docs/StorefrontApi.md#get_email_flow) | **GET** /storefront/{storefront_oid}/email/flows/{email_flow_uuid} | Get email flow
*UltracartClient::StorefrontApi* | [**get_email_flow_folder**](docs/StorefrontApi.md#get_email_flow_folder) | **GET** /storefront/{storefront_oid}/email/flow_folders/{email_flow_folder_uuid} | Get email flow folder
*UltracartClient::StorefrontApi* | [**get_email_flow_folders**](docs/StorefrontApi.md#get_email_flow_folders) | **GET** /storefront/{storefront_oid}/email/flow_folders | Get email flow folders
*UltracartClient::StorefrontApi* | [**get_email_flow_screenshots**](docs/StorefrontApi.md#get_email_flow_screenshots) | **GET** /storefront/{storefront_oid}/email/flows/{email_flow_uuid}/screenshots | Get email flow screenshots
*UltracartClient::StorefrontApi* | [**get_email_flows**](docs/StorefrontApi.md#get_email_flows) | **GET** /storefront/{storefront_oid}/email/flows | Get email flows
*UltracartClient::StorefrontApi* | [**get_email_global_settings**](docs/StorefrontApi.md#get_email_global_settings) | **GET** /storefront/email/global_settings | Get email globalsettings
*UltracartClient::StorefrontApi* | [**get_email_list**](docs/StorefrontApi.md#get_email_list) | **GET** /storefront/{storefront_oid}/email/lists/{email_list_uuid} | Get email list
*UltracartClient::StorefrontApi* | [**get_email_list_customer_editor_url**](docs/StorefrontApi.md#get_email_list_customer_editor_url) | **GET** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/customers/{email_customer_uuid}/editor_url | Get email list customer editor url
*UltracartClient::StorefrontApi* | [**get_email_list_customers**](docs/StorefrontApi.md#get_email_list_customers) | **GET** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/customers | Get email list customers
*UltracartClient::StorefrontApi* | [**get_email_list_segment_folder**](docs/StorefrontApi.md#get_email_list_segment_folder) | **GET** /storefront/{storefront_oid}/email/list_segment_folders/{email_list_segment_folder_uuid} | Get email campaign folder
*UltracartClient::StorefrontApi* | [**get_email_list_segment_folders**](docs/StorefrontApi.md#get_email_list_segment_folders) | **GET** /storefront/{storefront_oid}/email/list_segment_folders | Get email campaign folders
*UltracartClient::StorefrontApi* | [**get_email_lists**](docs/StorefrontApi.md#get_email_lists) | **GET** /storefront/{storefront_oid}/email/lists | Get email lists
*UltracartClient::StorefrontApi* | [**get_email_performance**](docs/StorefrontApi.md#get_email_performance) | **GET** /storefront/{storefront_oid}/email/performance | Get email performance
*UltracartClient::StorefrontApi* | [**get_email_plan**](docs/StorefrontApi.md#get_email_plan) | **GET** /storefront/{storefront_oid}/email/plan | Get email plan
*UltracartClient::StorefrontApi* | [**get_email_postcard**](docs/StorefrontApi.md#get_email_postcard) | **GET** /storefront/{storefront_oid}/email/postcards/{commseq_postcard_uuid} | Get email postcard
*UltracartClient::StorefrontApi* | [**get_email_postcards**](docs/StorefrontApi.md#get_email_postcards) | **GET** /storefront/{storefront_oid}/email/postcards | Get email postcards
*UltracartClient::StorefrontApi* | [**get_email_postcards_multiple**](docs/StorefrontApi.md#get_email_postcards_multiple) | **POST** /storefront/{storefront_oid}/email/postcards/multiple | Get email postcards multiple
*UltracartClient::StorefrontApi* | [**get_email_segment**](docs/StorefrontApi.md#get_email_segment) | **GET** /storefront/{storefront_oid}/email/segments/{email_segment_uuid} | Get email segment
*UltracartClient::StorefrontApi* | [**get_email_segment_customer_editor_url**](docs/StorefrontApi.md#get_email_segment_customer_editor_url) | **GET** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/customers/{email_customer_uuid}/editor_url | Get email segment customers editor URL
*UltracartClient::StorefrontApi* | [**get_email_segment_customers**](docs/StorefrontApi.md#get_email_segment_customers) | **GET** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/customers | Get email segment customers
*UltracartClient::StorefrontApi* | [**get_email_segments**](docs/StorefrontApi.md#get_email_segments) | **GET** /storefront/{storefront_oid}/email/segments | Get email segments
*UltracartClient::StorefrontApi* | [**get_email_sending_domain**](docs/StorefrontApi.md#get_email_sending_domain) | **GET** /storefront/email/sending_domain/{domain} | Get email sending domain
*UltracartClient::StorefrontApi* | [**get_email_sending_domain_status**](docs/StorefrontApi.md#get_email_sending_domain_status) | **POST** /storefront/email/sending_domains/{domain}/status | Get email sending domain status
*UltracartClient::StorefrontApi* | [**get_email_sending_domains**](docs/StorefrontApi.md#get_email_sending_domains) | **GET** /storefront/email/sending_domains | Get email sending domains
*UltracartClient::StorefrontApi* | [**get_email_settings**](docs/StorefrontApi.md#get_email_settings) | **GET** /storefront/{storefront_oid}/email/settings | Get email settings
*UltracartClient::StorefrontApi* | [**get_email_template**](docs/StorefrontApi.md#get_email_template) | **GET** /storefront/{storefront_oid}/email/templates/{email_template_oid} | Get email template
*UltracartClient::StorefrontApi* | [**get_email_templates**](docs/StorefrontApi.md#get_email_templates) | **GET** /storefront/{storefront_oid}/email/templates | Get email templates
*UltracartClient::StorefrontApi* | [**get_email_third_party_providers**](docs/StorefrontApi.md#get_email_third_party_providers) | **GET** /storefront/{storefront_oid}/email/third_party_providers | Get a list of third party email providers
*UltracartClient::StorefrontApi* | [**get_experiments**](docs/StorefrontApi.md#get_experiments) | **GET** /storefront/{storefront_oid}/experiments | Get experiments
*UltracartClient::StorefrontApi* | [**get_heatmap**](docs/StorefrontApi.md#get_heatmap) | **POST** /storefront/{storefront_oid}/screen_recordings/heatmap | Get screen recording heatmap
*UltracartClient::StorefrontApi* | [**get_heatmap_index**](docs/StorefrontApi.md#get_heatmap_index) | **POST** /storefront/{storefront_oid}/screen_recordings/heatmap/index | Get screen recording heatmap index
*UltracartClient::StorefrontApi* | [**get_histogram_property_names**](docs/StorefrontApi.md#get_histogram_property_names) | **GET** /storefront/{storefront_oid}/email/histogram/property_names | Get histogram property names
*UltracartClient::StorefrontApi* | [**get_histogram_property_values**](docs/StorefrontApi.md#get_histogram_property_values) | **GET** /storefront/{storefront_oid}/email/histogram/property_values | Get histogram property values
*UltracartClient::StorefrontApi* | [**get_library_filter_values**](docs/StorefrontApi.md#get_library_filter_values) | **GET** /storefront/code_library/filter_values | Get library values used to populate drop down boxes for filtering.
*UltracartClient::StorefrontApi* | [**get_library_item**](docs/StorefrontApi.md#get_library_item) | **GET** /storefront/code_library/{library_item_oid} | Get library item.
*UltracartClient::StorefrontApi* | [**get_library_item_published_versions**](docs/StorefrontApi.md#get_library_item_published_versions) | **GET** /storefront/code_library/{library_item_oid}/published_versions | Get all published versions for a library item.
*UltracartClient::StorefrontApi* | [**get_screen_recording**](docs/StorefrontApi.md#get_screen_recording) | **GET** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid} | Get screen recording
*UltracartClient::StorefrontApi* | [**get_screen_recording_page_view_data**](docs/StorefrontApi.md#get_screen_recording_page_view_data) | **GET** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid}/page_view_data/{screen_recording_page_view_uuid} | Get screen recording page view data
*UltracartClient::StorefrontApi* | [**get_screen_recording_segment**](docs/StorefrontApi.md#get_screen_recording_segment) | **GET** /storefront/{storefront_oid}/screen_recordings/segments/{screen_recording_segment_oid} | Get screen recording segment
*UltracartClient::StorefrontApi* | [**get_screen_recording_segments**](docs/StorefrontApi.md#get_screen_recording_segments) | **GET** /storefront/{storefront_oid}/screen_recordings/segments | Get screen recording segments
*UltracartClient::StorefrontApi* | [**get_screen_recording_settings**](docs/StorefrontApi.md#get_screen_recording_settings) | **GET** /storefront/{storefront_oid}/screen_recordings/settings | Get screen recording settings
*UltracartClient::StorefrontApi* | [**get_screen_recording_tags**](docs/StorefrontApi.md#get_screen_recording_tags) | **POST** /storefront/{storefront_oid}/screen_recordings/tags | Get tags used by screen recording
*UltracartClient::StorefrontApi* | [**get_screen_recordings_by_query**](docs/StorefrontApi.md#get_screen_recordings_by_query) | **POST** /storefront/{storefront_oid}/screen_recordings/query | Query screen recordings
*UltracartClient::StorefrontApi* | [**get_screen_recordings_by_segment**](docs/StorefrontApi.md#get_screen_recordings_by_segment) | **POST** /storefront/{storefront_oid}/screen_recordings/segments/{screen_recording_segment_oid}/query | Get screen recordings by segment
*UltracartClient::StorefrontApi* | [**get_store_front_pricing_tiers**](docs/StorefrontApi.md#get_store_front_pricing_tiers) | **GET** /storefront/pricing_tiers | Retrieve pricing tiers
*UltracartClient::StorefrontApi* | [**get_thumbnail_parameters**](docs/StorefrontApi.md#get_thumbnail_parameters) | **POST** /storefront/thumbnailParameters | Get thumbnail parameters
*UltracartClient::StorefrontApi* | [**get_transaction_email**](docs/StorefrontApi.md#get_transaction_email) | **GET** /storefront/{storefront_oid}/transaction_email/list/{email_id} | Gets a transaction email object
*UltracartClient::StorefrontApi* | [**get_transaction_email_list**](docs/StorefrontApi.md#get_transaction_email_list) | **GET** /storefront/{storefront_oid}/transaction_email/list | Gets a list of transaction email names
*UltracartClient::StorefrontApi* | [**get_transaction_email_screenshots**](docs/StorefrontApi.md#get_transaction_email_screenshots) | **GET** /storefront/{storefront_oid}/transaction_email/list/{email_id}/screenshots | Get transactional email screenshots
*UltracartClient::StorefrontApi* | [**global_unsubscribe**](docs/StorefrontApi.md#global_unsubscribe) | **POST** /storefront/{storefront_oid}/email/globalUnsubscribe | Globally unsubscribe a customer
*UltracartClient::StorefrontApi* | [**import_email_third_party_provider_list**](docs/StorefrontApi.md#import_email_third_party_provider_list) | **POST** /storefront/{storefront_oid}/email/third_party_providers/import | Import a third party provider list
*UltracartClient::StorefrontApi* | [**insert_email_campaign**](docs/StorefrontApi.md#insert_email_campaign) | **POST** /storefront/{storefront_oid}/email/campaigns | Insert email campaign
*UltracartClient::StorefrontApi* | [**insert_email_campaign_folder**](docs/StorefrontApi.md#insert_email_campaign_folder) | **POST** /storefront/{storefront_oid}/email/campaign_folders | Insert email campaign folder
*UltracartClient::StorefrontApi* | [**insert_email_commseq**](docs/StorefrontApi.md#insert_email_commseq) | **POST** /storefront/{storefront_oid}/email/commseqs | Insert email commseq
*UltracartClient::StorefrontApi* | [**insert_email_email**](docs/StorefrontApi.md#insert_email_email) | **POST** /storefront/{storefront_oid}/email/emails | Insert email email
*UltracartClient::StorefrontApi* | [**insert_email_flow**](docs/StorefrontApi.md#insert_email_flow) | **POST** /storefront/{storefront_oid}/email/flows | Insert email flow
*UltracartClient::StorefrontApi* | [**insert_email_flow_folder**](docs/StorefrontApi.md#insert_email_flow_folder) | **POST** /storefront/{storefront_oid}/email/flow_folders | Insert email flow folder
*UltracartClient::StorefrontApi* | [**insert_email_list**](docs/StorefrontApi.md#insert_email_list) | **POST** /storefront/{storefront_oid}/email/lists | Insert email list
*UltracartClient::StorefrontApi* | [**insert_email_list_segment_folder**](docs/StorefrontApi.md#insert_email_list_segment_folder) | **POST** /storefront/{storefront_oid}/email/list_segment_folders | Insert email campaign folder
*UltracartClient::StorefrontApi* | [**insert_email_postcard**](docs/StorefrontApi.md#insert_email_postcard) | **POST** /storefront/{storefront_oid}/email/postcards | Insert email postcard
*UltracartClient::StorefrontApi* | [**insert_email_segment**](docs/StorefrontApi.md#insert_email_segment) | **POST** /storefront/{storefront_oid}/email/segments | Insert email segment
*UltracartClient::StorefrontApi* | [**insert_screen_recording_segment**](docs/StorefrontApi.md#insert_screen_recording_segment) | **POST** /storefront/{storefront_oid}/screen_recordings/segments | Insert screen recording segment
*UltracartClient::StorefrontApi* | [**prepare_download_email_segment**](docs/StorefrontApi.md#prepare_download_email_segment) | **POST** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/downloadPrepare | Prepare download of email segment
*UltracartClient::StorefrontApi* | [**publish_library_item**](docs/StorefrontApi.md#publish_library_item) | **POST** /storefront/code_library/{library_item_oid}/publish | Publish library item.
*UltracartClient::StorefrontApi* | [**purchase_library_item**](docs/StorefrontApi.md#purchase_library_item) | **POST** /storefront/code_library/{library_item_oid}/purchase | Purchase public library item, which creates a copy of the item in your personal code library
*UltracartClient::StorefrontApi* | [**release_email_commseq_step_waiting**](docs/StorefrontApi.md#release_email_commseq_step_waiting) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/waiting/{commseq_step_uuid} | Release email communication sequence customers waiting at the specified step
*UltracartClient::StorefrontApi* | [**review**](docs/StorefrontApi.md#review) | **POST** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid}/review | Request a review of an email
*UltracartClient::StorefrontApi* | [**search**](docs/StorefrontApi.md#search) | **GET** /storefront/search | Searches for all matching values
*UltracartClient::StorefrontApi* | [**search2**](docs/StorefrontApi.md#search2) | **POST** /storefront/search | Searches for all matching values (using POST)
*UltracartClient::StorefrontApi* | [**search_email_list_customers**](docs/StorefrontApi.md#search_email_list_customers) | **GET** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/search | Search email list customers
*UltracartClient::StorefrontApi* | [**search_email_segment_customers**](docs/StorefrontApi.md#search_email_segment_customers) | **GET** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/search | Search email segment customers
*UltracartClient::StorefrontApi* | [**search_library_items**](docs/StorefrontApi.md#search_library_items) | **POST** /storefront/code_library/search | Retrieve library items
*UltracartClient::StorefrontApi* | [**search_published_items**](docs/StorefrontApi.md#search_published_items) | **POST** /storefront/code_library/search_published | Retrieve library items
*UltracartClient::StorefrontApi* | [**search_review_items**](docs/StorefrontApi.md#search_review_items) | **POST** /storefront/code_library/search_review | Retrieve library items needing review or rejected
*UltracartClient::StorefrontApi* | [**search_shared_items**](docs/StorefrontApi.md#search_shared_items) | **POST** /storefront/code_library/search_shared | Retrieve library items
*UltracartClient::StorefrontApi* | [**send_email_test**](docs/StorefrontApi.md#send_email_test) | **POST** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid}/test | Send email test
*UltracartClient::StorefrontApi* | [**send_postcard_test**](docs/StorefrontApi.md#send_postcard_test) | **POST** /storefront/{storefront_oid}/email/postcards/{commseq_postcard_uuid}/test | Send postcard test
*UltracartClient::StorefrontApi* | [**send_webhook_test**](docs/StorefrontApi.md#send_webhook_test) | **POST** /storefront/{storefront_oid}/email/webhooks/test | Send webhook test
*UltracartClient::StorefrontApi* | [**start_email_campaign**](docs/StorefrontApi.md#start_email_campaign) | **PUT** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid}/start | Start email campaign
*UltracartClient::StorefrontApi* | [**subscribe_to_email_list**](docs/StorefrontApi.md#subscribe_to_email_list) | **POST** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/subscribe | Subscribe customers to email list
*UltracartClient::StorefrontApi* | [**unfavorite_screen_recording**](docs/StorefrontApi.md#unfavorite_screen_recording) | **DELETE** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid}/favorite | Remove favorite flag on screen recording
*UltracartClient::StorefrontApi* | [**update_email_campaign**](docs/StorefrontApi.md#update_email_campaign) | **PUT** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid} | Update email campaign
*UltracartClient::StorefrontApi* | [**update_email_campaign_folder**](docs/StorefrontApi.md#update_email_campaign_folder) | **PUT** /storefront/{storefront_oid}/email/campaign_folders/{email_campaign_folder_uuid} | Update email campaign folder
*UltracartClient::StorefrontApi* | [**update_email_commseq**](docs/StorefrontApi.md#update_email_commseq) | **PUT** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid} | Update email commseq
*UltracartClient::StorefrontApi* | [**update_email_customer**](docs/StorefrontApi.md#update_email_customer) | **PUT** /storefront/{storefront_oid}/email/customers/{email_customer_uuid} | Update email customer
*UltracartClient::StorefrontApi* | [**update_email_email**](docs/StorefrontApi.md#update_email_email) | **PUT** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid} | Update email email
*UltracartClient::StorefrontApi* | [**update_email_flow**](docs/StorefrontApi.md#update_email_flow) | **PUT** /storefront/{storefront_oid}/email/flows/{email_flow_uuid} | Update email flow
*UltracartClient::StorefrontApi* | [**update_email_flow_folder**](docs/StorefrontApi.md#update_email_flow_folder) | **PUT** /storefront/{storefront_oid}/email/flow_folders/{email_flow_folder_uuid} | Update email flow folder
*UltracartClient::StorefrontApi* | [**update_email_global_settings**](docs/StorefrontApi.md#update_email_global_settings) | **POST** /storefront/email/global_settings | Update email global settings
*UltracartClient::StorefrontApi* | [**update_email_list**](docs/StorefrontApi.md#update_email_list) | **PUT** /storefront/{storefront_oid}/email/lists/{email_list_uuid} | Update email list
*UltracartClient::StorefrontApi* | [**update_email_list_segment_folder**](docs/StorefrontApi.md#update_email_list_segment_folder) | **PUT** /storefront/{storefront_oid}/email/list_segment_folders/{email_list_segment_folder_uuid} | Update email campaign folder
*UltracartClient::StorefrontApi* | [**update_email_plan**](docs/StorefrontApi.md#update_email_plan) | **POST** /storefront/{storefront_oid}/email/plan | Update email plan
*UltracartClient::StorefrontApi* | [**update_email_postcard**](docs/StorefrontApi.md#update_email_postcard) | **PUT** /storefront/{storefront_oid}/email/postcards/{commseq_postcard_uuid} | Update email postcard
*UltracartClient::StorefrontApi* | [**update_email_segment**](docs/StorefrontApi.md#update_email_segment) | **PUT** /storefront/{storefront_oid}/email/segments/{email_segment_uuid} | Update email segment
*UltracartClient::StorefrontApi* | [**update_email_settings**](docs/StorefrontApi.md#update_email_settings) | **POST** /storefront/{storefront_oid}/email/settings | Update email settings
*UltracartClient::StorefrontApi* | [**update_experiment**](docs/StorefrontApi.md#update_experiment) | **PUT** /storefront/{storefront_oid}/experiments/{storefront_experiment_oid} | Update experiment
*UltracartClient::StorefrontApi* | [**update_library_item**](docs/StorefrontApi.md#update_library_item) | **PUT** /storefront/code_library/{library_item_oid} | Update library item. Note that only certain fields may be updated via this method.
*UltracartClient::StorefrontApi* | [**update_screen_recording_merchant_notes**](docs/StorefrontApi.md#update_screen_recording_merchant_notes) | **POST** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid}/merchant_notes | Update merchant notes on a screen recording
*UltracartClient::StorefrontApi* | [**update_screen_recording_segment**](docs/StorefrontApi.md#update_screen_recording_segment) | **POST** /storefront/{storefront_oid}/screen_recordings/segments/{screen_recording_segment_oid} | Update screen recording segment
*UltracartClient::StorefrontApi* | [**update_screen_recording_settings**](docs/StorefrontApi.md#update_screen_recording_settings) | **POST** /storefront/{storefront_oid}/screen_recordings/settings | Update screen recording settings
*UltracartClient::StorefrontApi* | [**update_screen_recording_tags**](docs/StorefrontApi.md#update_screen_recording_tags) | **POST** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid}/tags | Update tags on a screen recording
*UltracartClient::StorefrontApi* | [**update_transaction_email**](docs/StorefrontApi.md#update_transaction_email) | **PUT** /storefront/{storefront_oid}/transaction_email/list/{email_id} | Updates a transaction email object
*UltracartClient::TaxApi* | [**delete_tax_provider_self_city**](docs/TaxApi.md#delete_tax_provider_self_city) | **DELETE** /tax/providers/self/city/{city} | Deletes a Self tax provider city
*UltracartClient::TaxApi* | [**delete_tax_provider_self_country**](docs/TaxApi.md#delete_tax_provider_self_country) | **DELETE** /tax/providers/self/country/{countryCode} | Deletes a Self tax provider country
*UltracartClient::TaxApi* | [**delete_tax_provider_self_county**](docs/TaxApi.md#delete_tax_provider_self_county) | **DELETE** /tax/providers/self/county/{county} | Deletes a Self tax provider county
*UltracartClient::TaxApi* | [**delete_tax_provider_self_postal_code**](docs/TaxApi.md#delete_tax_provider_self_postal_code) | **DELETE** /tax/providers/self/postalCode/{postal_code} | Deletes a Self tax provider postalCode
*UltracartClient::TaxApi* | [**delete_tax_provider_self_state**](docs/TaxApi.md#delete_tax_provider_self_state) | **DELETE** /tax/providers/self/state/{stateCode} | Deletes a Self tax provider state
*UltracartClient::TaxApi* | [**get_tax_provider_avalara**](docs/TaxApi.md#get_tax_provider_avalara) | **GET** /tax/providers/avalara | Retrieve the Avalara tax provider
*UltracartClient::TaxApi* | [**get_tax_provider_avalara_companies**](docs/TaxApi.md#get_tax_provider_avalara_companies) | **POST** /tax/providers/avalara/companies | Returns Avalara Tax companies configured by the merchant
*UltracartClient::TaxApi* | [**get_tax_provider_avalara_test**](docs/TaxApi.md#get_tax_provider_avalara_test) | **GET** /tax/providers/avalara/test | Attempts to connect to Avalara and returns back the response
*UltracartClient::TaxApi* | [**get_tax_provider_self**](docs/TaxApi.md#get_tax_provider_self) | **GET** /tax/providers/self | Retrieve the Self tax provider
*UltracartClient::TaxApi* | [**get_tax_provider_self_countries**](docs/TaxApi.md#get_tax_provider_self_countries) | **GET** /tax/providers/self/countries | Retrieve the Self tax provider countries
*UltracartClient::TaxApi* | [**get_tax_provider_self_regions_by_country_code**](docs/TaxApi.md#get_tax_provider_self_regions_by_country_code) | **GET** /tax/providers/self/regions/{countryCode} | Retrieve the Self tax provider regions for a given country code
*UltracartClient::TaxApi* | [**get_tax_provider_sovos**](docs/TaxApi.md#get_tax_provider_sovos) | **GET** /tax/providers/sovos | Retrieve the Sovos tax provider
*UltracartClient::TaxApi* | [**get_tax_provider_sovos_test**](docs/TaxApi.md#get_tax_provider_sovos_test) | **GET** /tax/providers/sovos/test | Attempts to connect to Sovos and returns back the response
*UltracartClient::TaxApi* | [**get_tax_provider_tax_jar**](docs/TaxApi.md#get_tax_provider_tax_jar) | **GET** /tax/providers/taxjar | Retrieve the TaxJar tax provider
*UltracartClient::TaxApi* | [**get_tax_provider_tax_jar_test**](docs/TaxApi.md#get_tax_provider_tax_jar_test) | **GET** /tax/providers/taxjar/test | Attempts to connect to TaxJar and returns back the response
*UltracartClient::TaxApi* | [**get_tax_provider_ultra_cart**](docs/TaxApi.md#get_tax_provider_ultra_cart) | **GET** /tax/providers/ultracart | Retrieve the UltraCart tax provider
*UltracartClient::TaxApi* | [**get_tax_providers**](docs/TaxApi.md#get_tax_providers) | **GET** /tax/providers | Retrieve tax methods
*UltracartClient::TaxApi* | [**set_active_tax_provider**](docs/TaxApi.md#set_active_tax_provider) | **POST** /tax/providers/setActive/{providerName} | Toggle a tax provider to active
*UltracartClient::TaxApi* | [**update_tax_provider_avalara**](docs/TaxApi.md#update_tax_provider_avalara) | **POST** /tax/providers/avalara | Update the Avalara tax provider
*UltracartClient::TaxApi* | [**update_tax_provider_self**](docs/TaxApi.md#update_tax_provider_self) | **POST** /tax/providers/self | Update the Self tax provider
*UltracartClient::TaxApi* | [**update_tax_provider_self_city**](docs/TaxApi.md#update_tax_provider_self_city) | **POST** /tax/providers/self/city/{city} | Updates a Self tax provider city
*UltracartClient::TaxApi* | [**update_tax_provider_self_country**](docs/TaxApi.md#update_tax_provider_self_country) | **POST** /tax/providers/self/country/{countryCode} | Updates a Self tax provider country
*UltracartClient::TaxApi* | [**update_tax_provider_self_county**](docs/TaxApi.md#update_tax_provider_self_county) | **POST** /tax/providers/self/county/{county} | Updates a Self tax provider county
*UltracartClient::TaxApi* | [**update_tax_provider_self_postal_code**](docs/TaxApi.md#update_tax_provider_self_postal_code) | **POST** /tax/providers/self/postalCode/{postal_code} | Updates a Self tax provider postalCode
*UltracartClient::TaxApi* | [**update_tax_provider_self_state**](docs/TaxApi.md#update_tax_provider_self_state) | **POST** /tax/providers/self/state/{stateCode} | Updates a Self tax provider state
*UltracartClient::TaxApi* | [**update_tax_provider_sovos**](docs/TaxApi.md#update_tax_provider_sovos) | **POST** /tax/providers/sovos | Update the Sovos tax provider
*UltracartClient::TaxApi* | [**update_tax_provider_tax_jar**](docs/TaxApi.md#update_tax_provider_tax_jar) | **POST** /tax/providers/taxjar | Update the TaxJar tax provider
*UltracartClient::TaxApi* | [**update_tax_provider_ultra_cart**](docs/TaxApi.md#update_tax_provider_ultra_cart) | **POST** /tax/providers/ultracart | Update the UltraCart tax provider
*UltracartClient::UserApi* | [**delete_group**](docs/UserApi.md#delete_group) | **DELETE** /user/groups/{group_oid} | Delete a group
*UltracartClient::UserApi* | [**delete_user**](docs/UserApi.md#delete_user) | **DELETE** /user/users/{user_id} | Delete a user
*UltracartClient::UserApi* | [**get_group**](docs/UserApi.md#get_group) | **GET** /user/groups/{group_oid} | Retrieve a group
*UltracartClient::UserApi* | [**get_groups**](docs/UserApi.md#get_groups) | **GET** /user/groups | Get groups
*UltracartClient::UserApi* | [**get_user**](docs/UserApi.md#get_user) | **GET** /user/users/{user_id} | Retrieve a user
*UltracartClient::UserApi* | [**get_user_logins**](docs/UserApi.md#get_user_logins) | **GET** /user/users/{user_id}/logins | Retrieve a user's login history
*UltracartClient::UserApi* | [**get_users**](docs/UserApi.md#get_users) | **GET** /user/users | Get users
*UltracartClient::UserApi* | [**insert_group**](docs/UserApi.md#insert_group) | **POST** /user/groups | Insert a group
*UltracartClient::UserApi* | [**insert_user**](docs/UserApi.md#insert_user) | **POST** /user/users | Insert a user
*UltracartClient::UserApi* | [**update_group**](docs/UserApi.md#update_group) | **PUT** /user/groups/{group_oid} | Update a group
*UltracartClient::UserApi* | [**update_user**](docs/UserApi.md#update_user) | **PUT** /user/users/{user_id} | Update a user
*UltracartClient::WebhookApi* | [**delete_webhook**](docs/WebhookApi.md#delete_webhook) | **DELETE** /webhook/webhooks/{webhookOid} | Delete a webhook
*UltracartClient::WebhookApi* | [**delete_webhook_by_url**](docs/WebhookApi.md#delete_webhook_by_url) | **DELETE** /webhook/webhooks | Delete a webhook by URL
*UltracartClient::WebhookApi* | [**get_webhook_log**](docs/WebhookApi.md#get_webhook_log) | **GET** /webhook/webhooks/{webhookOid}/logs/{requestId} | Retrieve an individual log
*UltracartClient::WebhookApi* | [**get_webhook_log_summaries**](docs/WebhookApi.md#get_webhook_log_summaries) | **GET** /webhook/webhooks/{webhookOid}/logs | Retrieve the log summaries
*UltracartClient::WebhookApi* | [**get_webhooks**](docs/WebhookApi.md#get_webhooks) | **GET** /webhook/webhooks | Retrieve webhooks
*UltracartClient::WebhookApi* | [**insert_webhook**](docs/WebhookApi.md#insert_webhook) | **POST** /webhook/webhooks | Add a webhook
*UltracartClient::WebhookApi* | [**resend_event**](docs/WebhookApi.md#resend_event) | **POST** /webhook/webhooks/{webhookOid}/reflow/{eventName} | Resend events to the webhook endpoint.
*UltracartClient::WebhookApi* | [**update_webhook**](docs/WebhookApi.md#update_webhook) | **PUT** /webhook/webhooks/{webhookOid} | Update a webhook


## Documentation for Models

 - [UltracartClient::AccountsReceivableRetryConfig](docs/AccountsReceivableRetryConfig.md)
 - [UltracartClient::AccountsReceivableRetryConfigResponse](docs/AccountsReceivableRetryConfigResponse.md)
 - [UltracartClient::AccountsReceivableRetryDayActivity](docs/AccountsReceivableRetryDayActivity.md)
 - [UltracartClient::AccountsReceivableRetryStatAccount](docs/AccountsReceivableRetryStatAccount.md)
 - [UltracartClient::AccountsReceivableRetryStatMetrics](docs/AccountsReceivableRetryStatMetrics.md)
 - [UltracartClient::AccountsReceivableRetryStatRevenue](docs/AccountsReceivableRetryStatRevenue.md)
 - [UltracartClient::AccountsReceivableRetryStatsResponse](docs/AccountsReceivableRetryStatsResponse.md)
 - [UltracartClient::Activity](docs/Activity.md)
 - [UltracartClient::AddLibraryItemRequest](docs/AddLibraryItemRequest.md)
 - [UltracartClient::AffiliateClick](docs/AffiliateClick.md)
 - [UltracartClient::AffiliateClickQuery](docs/AffiliateClickQuery.md)
 - [UltracartClient::AffiliateClicksResponse](docs/AffiliateClicksResponse.md)
 - [UltracartClient::AffiliateLedger](docs/AffiliateLedger.md)
 - [UltracartClient::AffiliateLedgerQuery](docs/AffiliateLedgerQuery.md)
 - [UltracartClient::AffiliateLedgersResponse](docs/AffiliateLedgersResponse.md)
 - [UltracartClient::AffiliateLink](docs/AffiliateLink.md)
 - [UltracartClient::ApiUserApplicationProfile](docs/ApiUserApplicationProfile.md)
 - [UltracartClient::ApplyLibraryItemRequest](docs/ApplyLibraryItemRequest.md)
 - [UltracartClient::ApplyLibraryItemResponse](docs/ApplyLibraryItemResponse.md)
 - [UltracartClient::AutoOrder](docs/AutoOrder.md)
 - [UltracartClient::AutoOrderItem](docs/AutoOrderItem.md)
 - [UltracartClient::AutoOrderItemFutureSchedule](docs/AutoOrderItemFutureSchedule.md)
 - [UltracartClient::AutoOrderItemOption](docs/AutoOrderItemOption.md)
 - [UltracartClient::AutoOrderItemSimpleSchedule](docs/AutoOrderItemSimpleSchedule.md)
 - [UltracartClient::AutoOrderQuery](docs/AutoOrderQuery.md)
 - [UltracartClient::AutoOrderQueryBatch](docs/AutoOrderQueryBatch.md)
 - [UltracartClient::AutoOrderResponse](docs/AutoOrderResponse.md)
 - [UltracartClient::AutoOrdersRequest](docs/AutoOrdersRequest.md)
 - [UltracartClient::AutoOrdersResponse](docs/AutoOrdersResponse.md)
 - [UltracartClient::AvalaraConfig](docs/AvalaraConfig.md)
 - [UltracartClient::BaseResponse](docs/BaseResponse.md)
 - [UltracartClient::Cart](docs/Cart.md)
 - [UltracartClient::CartAffiliate](docs/CartAffiliate.md)
 - [UltracartClient::CartAffirmCheckoutResponse](docs/CartAffirmCheckoutResponse.md)
 - [UltracartClient::CartBilling](docs/CartBilling.md)
 - [UltracartClient::CartBuysafe](docs/CartBuysafe.md)
 - [UltracartClient::CartCheckout](docs/CartCheckout.md)
 - [UltracartClient::CartCoupon](docs/CartCoupon.md)
 - [UltracartClient::CartCurrencyConversion](docs/CartCurrencyConversion.md)
 - [UltracartClient::CartCustomerProfile](docs/CartCustomerProfile.md)
 - [UltracartClient::CartCustomerProfileAddress](docs/CartCustomerProfileAddress.md)
 - [UltracartClient::CartCustomerProfileCreditCard](docs/CartCustomerProfileCreditCard.md)
 - [UltracartClient::CartFinalizeOrderRequest](docs/CartFinalizeOrderRequest.md)
 - [UltracartClient::CartFinalizeOrderRequestOptions](docs/CartFinalizeOrderRequestOptions.md)
 - [UltracartClient::CartFinalizeOrderResponse](docs/CartFinalizeOrderResponse.md)
 - [UltracartClient::CartGift](docs/CartGift.md)
 - [UltracartClient::CartGiftCertificate](docs/CartGiftCertificate.md)
 - [UltracartClient::CartItem](docs/CartItem.md)
 - [UltracartClient::CartItemAttribute](docs/CartItemAttribute.md)
 - [UltracartClient::CartItemMultimedia](docs/CartItemMultimedia.md)
 - [UltracartClient::CartItemMultimediaThumbnail](docs/CartItemMultimediaThumbnail.md)
 - [UltracartClient::CartItemOption](docs/CartItemOption.md)
 - [UltracartClient::CartItemOptionValue](docs/CartItemOptionValue.md)
 - [UltracartClient::CartItemPhysical](docs/CartItemPhysical.md)
 - [UltracartClient::CartItemVariationSelection](docs/CartItemVariationSelection.md)
 - [UltracartClient::CartKitComponentOption](docs/CartKitComponentOption.md)
 - [UltracartClient::CartMarketing](docs/CartMarketing.md)
 - [UltracartClient::CartPayment](docs/CartPayment.md)
 - [UltracartClient::CartPaymentAffirm](docs/CartPaymentAffirm.md)
 - [UltracartClient::CartPaymentAmazon](docs/CartPaymentAmazon.md)
 - [UltracartClient::CartPaymentCheck](docs/CartPaymentCheck.md)
 - [UltracartClient::CartPaymentCreditCard](docs/CartPaymentCreditCard.md)
 - [UltracartClient::CartPaymentPurchaseOrder](docs/CartPaymentPurchaseOrder.md)
 - [UltracartClient::CartProfileLoginRequest](docs/CartProfileLoginRequest.md)
 - [UltracartClient::CartProfileLoginResponse](docs/CartProfileLoginResponse.md)
 - [UltracartClient::CartProfileRegisterRequest](docs/CartProfileRegisterRequest.md)
 - [UltracartClient::CartProfileRegisterResponse](docs/CartProfileRegisterResponse.md)
 - [UltracartClient::CartProperty](docs/CartProperty.md)
 - [UltracartClient::CartResponse](docs/CartResponse.md)
 - [UltracartClient::CartSettings](docs/CartSettings.md)
 - [UltracartClient::CartSettingsBilling](docs/CartSettingsBilling.md)
 - [UltracartClient::CartSettingsGift](docs/CartSettingsGift.md)
 - [UltracartClient::CartSettingsGiftWrap](docs/CartSettingsGiftWrap.md)
 - [UltracartClient::CartSettingsPayment](docs/CartSettingsPayment.md)
 - [UltracartClient::CartSettingsPaymentAmazon](docs/CartSettingsPaymentAmazon.md)
 - [UltracartClient::CartSettingsPaymentCreditCard](docs/CartSettingsPaymentCreditCard.md)
 - [UltracartClient::CartSettingsPaymentPayPal](docs/CartSettingsPaymentPayPal.md)
 - [UltracartClient::CartSettingsProvince](docs/CartSettingsProvince.md)
 - [UltracartClient::CartSettingsShipping](docs/CartSettingsShipping.md)
 - [UltracartClient::CartSettingsShippingCalendar](docs/CartSettingsShippingCalendar.md)
 - [UltracartClient::CartSettingsShippingEstimate](docs/CartSettingsShippingEstimate.md)
 - [UltracartClient::CartSettingsTaxes](docs/CartSettingsTaxes.md)
 - [UltracartClient::CartSettingsTerms](docs/CartSettingsTerms.md)
 - [UltracartClient::CartShipping](docs/CartShipping.md)
 - [UltracartClient::CartSummary](docs/CartSummary.md)
 - [UltracartClient::CartTaxes](docs/CartTaxes.md)
 - [UltracartClient::CartUpsellAfter](docs/CartUpsellAfter.md)
 - [UltracartClient::CartValidationRequest](docs/CartValidationRequest.md)
 - [UltracartClient::CartValidationResponse](docs/CartValidationResponse.md)
 - [UltracartClient::ChargebackDispute](docs/ChargebackDispute.md)
 - [UltracartClient::ChargebackDisputeResponse](docs/ChargebackDisputeResponse.md)
 - [UltracartClient::ChargebackDisputesResponse](docs/ChargebackDisputesResponse.md)
 - [UltracartClient::CheckoutAllowedCountriesResponse](docs/CheckoutAllowedCountriesResponse.md)
 - [UltracartClient::CheckoutHandoffRequest](docs/CheckoutHandoffRequest.md)
 - [UltracartClient::CheckoutHandoffResponse](docs/CheckoutHandoffResponse.md)
 - [UltracartClient::CheckoutSetupBrowserKeyRequest](docs/CheckoutSetupBrowserKeyRequest.md)
 - [UltracartClient::CheckoutSetupBrowserKeyResponse](docs/CheckoutSetupBrowserKeyResponse.md)
 - [UltracartClient::CheckoutStateProvinceResponse](docs/CheckoutStateProvinceResponse.md)
 - [UltracartClient::CityStateZip](docs/CityStateZip.md)
 - [UltracartClient::CountriesResponse](docs/CountriesResponse.md)
 - [UltracartClient::Country](docs/Country.md)
 - [UltracartClient::Coupon](docs/Coupon.md)
 - [UltracartClient::CouponAmountOffItems](docs/CouponAmountOffItems.md)
 - [UltracartClient::CouponAmountOffShipping](docs/CouponAmountOffShipping.md)
 - [UltracartClient::CouponAmountOffShippingWithItemsPurchase](docs/CouponAmountOffShippingWithItemsPurchase.md)
 - [UltracartClient::CouponAmountOffSubtotal](docs/CouponAmountOffSubtotal.md)
 - [UltracartClient::CouponAmountOffSubtotalAndShipping](docs/CouponAmountOffSubtotalAndShipping.md)
 - [UltracartClient::CouponAmountOffSubtotalFreeShippingWithPurchase](docs/CouponAmountOffSubtotalFreeShippingWithPurchase.md)
 - [UltracartClient::CouponAmountOffSubtotalWithBlockPurchase](docs/CouponAmountOffSubtotalWithBlockPurchase.md)
 - [UltracartClient::CouponAmountOffSubtotalWithItemsPurchase](docs/CouponAmountOffSubtotalWithItemsPurchase.md)
 - [UltracartClient::CouponAmountOffSubtotalWithPurchase](docs/CouponAmountOffSubtotalWithPurchase.md)
 - [UltracartClient::CouponAutoApplyCondition](docs/CouponAutoApplyCondition.md)
 - [UltracartClient::CouponAutoApplyConditions](docs/CouponAutoApplyConditions.md)
 - [UltracartClient::CouponAutomaticallyApplyCouponCodes](docs/CouponAutomaticallyApplyCouponCodes.md)
 - [UltracartClient::CouponBuyOneGetOneLimit](docs/CouponBuyOneGetOneLimit.md)
 - [UltracartClient::CouponCodesRequest](docs/CouponCodesRequest.md)
 - [UltracartClient::CouponCodesResponse](docs/CouponCodesResponse.md)
 - [UltracartClient::CouponDeletesRequest](docs/CouponDeletesRequest.md)
 - [UltracartClient::CouponDiscountItemWithItemPurchase](docs/CouponDiscountItemWithItemPurchase.md)
 - [UltracartClient::CouponDiscountItems](docs/CouponDiscountItems.md)
 - [UltracartClient::CouponEditorValues](docs/CouponEditorValues.md)
 - [UltracartClient::CouponExistsResponse](docs/CouponExistsResponse.md)
 - [UltracartClient::CouponFreeItemAndShippingWithSubtotal](docs/CouponFreeItemAndShippingWithSubtotal.md)
 - [UltracartClient::CouponFreeItemWithItemPurchase](docs/CouponFreeItemWithItemPurchase.md)
 - [UltracartClient::CouponFreeItemWithSubtotal](docs/CouponFreeItemWithSubtotal.md)
 - [UltracartClient::CouponFreeItemsWithItemPurchase](docs/CouponFreeItemsWithItemPurchase.md)
 - [UltracartClient::CouponFreeItemsWithMixMatchPurchase](docs/CouponFreeItemsWithMixMatchPurchase.md)
 - [UltracartClient::CouponFreeShipping](docs/CouponFreeShipping.md)
 - [UltracartClient::CouponFreeShippingSpecificItems](docs/CouponFreeShippingSpecificItems.md)
 - [UltracartClient::CouponFreeShippingWithItemsPurchase](docs/CouponFreeShippingWithItemsPurchase.md)
 - [UltracartClient::CouponFreeShippingWithSubtotal](docs/CouponFreeShippingWithSubtotal.md)
 - [UltracartClient::CouponItemSearchResult](docs/CouponItemSearchResult.md)
 - [UltracartClient::CouponItemSearchResultsResponse](docs/CouponItemSearchResultsResponse.md)
 - [UltracartClient::CouponMultipleAmountsOffItems](docs/CouponMultipleAmountsOffItems.md)
 - [UltracartClient::CouponNoDiscount](docs/CouponNoDiscount.md)
 - [UltracartClient::CouponPercentOffItemWithItemsQuantityPurchase](docs/CouponPercentOffItemWithItemsQuantityPurchase.md)
 - [UltracartClient::CouponPercentOffItems](docs/CouponPercentOffItems.md)
 - [UltracartClient::CouponPercentOffItemsAndFreeShipping](docs/CouponPercentOffItemsAndFreeShipping.md)
 - [UltracartClient::CouponPercentOffItemsWithItemsPurchase](docs/CouponPercentOffItemsWithItemsPurchase.md)
 - [UltracartClient::CouponPercentOffMsrpItems](docs/CouponPercentOffMsrpItems.md)
 - [UltracartClient::CouponPercentOffRetailPriceItems](docs/CouponPercentOffRetailPriceItems.md)
 - [UltracartClient::CouponPercentOffShipping](docs/CouponPercentOffShipping.md)
 - [UltracartClient::CouponPercentOffSubtotal](docs/CouponPercentOffSubtotal.md)
 - [UltracartClient::CouponPercentOffSubtotalAndFreeShipping](docs/CouponPercentOffSubtotalAndFreeShipping.md)
 - [UltracartClient::CouponPercentOffSubtotalLimit](docs/CouponPercentOffSubtotalLimit.md)
 - [UltracartClient::CouponPercentOffSubtotalWithItemsPurchase](docs/CouponPercentOffSubtotalWithItemsPurchase.md)
 - [UltracartClient::CouponPercentOffSubtotalWithSubtotal](docs/CouponPercentOffSubtotalWithSubtotal.md)
 - [UltracartClient::CouponQuery](docs/CouponQuery.md)
 - [UltracartClient::CouponResponse](docs/CouponResponse.md)
 - [UltracartClient::CouponRestriction](docs/CouponRestriction.md)
 - [UltracartClient::CouponTierAmount](docs/CouponTierAmount.md)
 - [UltracartClient::CouponTierItemDiscount](docs/CouponTierItemDiscount.md)
 - [UltracartClient::CouponTierPercent](docs/CouponTierPercent.md)
 - [UltracartClient::CouponTierQuantityAmount](docs/CouponTierQuantityAmount.md)
 - [UltracartClient::CouponTierQuantityPercent](docs/CouponTierQuantityPercent.md)
 - [UltracartClient::CouponTieredAmountOffItems](docs/CouponTieredAmountOffItems.md)
 - [UltracartClient::CouponTieredAmountOffSubtotal](docs/CouponTieredAmountOffSubtotal.md)
 - [UltracartClient::CouponTieredPercentOffItems](docs/CouponTieredPercentOffItems.md)
 - [UltracartClient::CouponTieredPercentOffShipping](docs/CouponTieredPercentOffShipping.md)
 - [UltracartClient::CouponTieredPercentOffSubtotal](docs/CouponTieredPercentOffSubtotal.md)
 - [UltracartClient::CouponType](docs/CouponType.md)
 - [UltracartClient::CouponsRequest](docs/CouponsRequest.md)
 - [UltracartClient::CouponsResponse](docs/CouponsResponse.md)
 - [UltracartClient::Currency](docs/Currency.md)
 - [UltracartClient::Customer](docs/Customer.md)
 - [UltracartClient::CustomerActivity](docs/CustomerActivity.md)
 - [UltracartClient::CustomerAffiliate](docs/CustomerAffiliate.md)
 - [UltracartClient::CustomerAttachment](docs/CustomerAttachment.md)
 - [UltracartClient::CustomerBilling](docs/CustomerBilling.md)
 - [UltracartClient::CustomerCard](docs/CustomerCard.md)
 - [UltracartClient::CustomerEditorValues](docs/CustomerEditorValues.md)
 - [UltracartClient::CustomerEmail](docs/CustomerEmail.md)
 - [UltracartClient::CustomerEmailListChanges](docs/CustomerEmailListChanges.md)
 - [UltracartClient::CustomerLoyalty](docs/CustomerLoyalty.md)
 - [UltracartClient::CustomerLoyaltyLedger](docs/CustomerLoyaltyLedger.md)
 - [UltracartClient::CustomerLoyaltyRedemption](docs/CustomerLoyaltyRedemption.md)
 - [UltracartClient::CustomerOrdersSummary](docs/CustomerOrdersSummary.md)
 - [UltracartClient::CustomerPricingTier](docs/CustomerPricingTier.md)
 - [UltracartClient::CustomerPrivacy](docs/CustomerPrivacy.md)
 - [UltracartClient::CustomerQuery](docs/CustomerQuery.md)
 - [UltracartClient::CustomerQuotesSummary](docs/CustomerQuotesSummary.md)
 - [UltracartClient::CustomerResponse](docs/CustomerResponse.md)
 - [UltracartClient::CustomerReviewer](docs/CustomerReviewer.md)
 - [UltracartClient::CustomerShipping](docs/CustomerShipping.md)
 - [UltracartClient::CustomerSoftwareEntitlement](docs/CustomerSoftwareEntitlement.md)
 - [UltracartClient::CustomerTag](docs/CustomerTag.md)
 - [UltracartClient::CustomerTaxCodes](docs/CustomerTaxCodes.md)
 - [UltracartClient::CustomersResponse](docs/CustomersResponse.md)
 - [UltracartClient::DataTablesServerSideResponse](docs/DataTablesServerSideResponse.md)
 - [UltracartClient::DelayAutoOrdersResponse](docs/DelayAutoOrdersResponse.md)
 - [UltracartClient::Distance](docs/Distance.md)
 - [UltracartClient::DistributionCenter](docs/DistributionCenter.md)
 - [UltracartClient::DistributionCentersResponse](docs/DistributionCentersResponse.md)
 - [UltracartClient::EmailBaseTemplateListResponse](docs/EmailBaseTemplateListResponse.md)
 - [UltracartClient::EmailCampaign](docs/EmailCampaign.md)
 - [UltracartClient::EmailCampaignFolder](docs/EmailCampaignFolder.md)
 - [UltracartClient::EmailCampaignFolderResponse](docs/EmailCampaignFolderResponse.md)
 - [UltracartClient::EmailCampaignFoldersResponse](docs/EmailCampaignFoldersResponse.md)
 - [UltracartClient::EmailCampaignResponse](docs/EmailCampaignResponse.md)
 - [UltracartClient::EmailCampaignsResponse](docs/EmailCampaignsResponse.md)
 - [UltracartClient::EmailClick](docs/EmailClick.md)
 - [UltracartClient::EmailClicksResponse](docs/EmailClicksResponse.md)
 - [UltracartClient::EmailCommseq](docs/EmailCommseq.md)
 - [UltracartClient::EmailCommseqEmail](docs/EmailCommseqEmail.md)
 - [UltracartClient::EmailCommseqEmailResponse](docs/EmailCommseqEmailResponse.md)
 - [UltracartClient::EmailCommseqEmailSendTestRequest](docs/EmailCommseqEmailSendTestRequest.md)
 - [UltracartClient::EmailCommseqEmailSendTestResponse](docs/EmailCommseqEmailSendTestResponse.md)
 - [UltracartClient::EmailCommseqEmailsRequest](docs/EmailCommseqEmailsRequest.md)
 - [UltracartClient::EmailCommseqEmailsResponse](docs/EmailCommseqEmailsResponse.md)
 - [UltracartClient::EmailCommseqPostcard](docs/EmailCommseqPostcard.md)
 - [UltracartClient::EmailCommseqPostcardResponse](docs/EmailCommseqPostcardResponse.md)
 - [UltracartClient::EmailCommseqPostcardSendTestRequest](docs/EmailCommseqPostcardSendTestRequest.md)
 - [UltracartClient::EmailCommseqPostcardSendTestResponse](docs/EmailCommseqPostcardSendTestResponse.md)
 - [UltracartClient::EmailCommseqPostcardsRequest](docs/EmailCommseqPostcardsRequest.md)
 - [UltracartClient::EmailCommseqPostcardsResponse](docs/EmailCommseqPostcardsResponse.md)
 - [UltracartClient::EmailCommseqResponse](docs/EmailCommseqResponse.md)
 - [UltracartClient::EmailCommseqStat](docs/EmailCommseqStat.md)
 - [UltracartClient::EmailCommseqStatResponse](docs/EmailCommseqStatResponse.md)
 - [UltracartClient::EmailCommseqStep](docs/EmailCommseqStep.md)
 - [UltracartClient::EmailCommseqStepLog](docs/EmailCommseqStepLog.md)
 - [UltracartClient::EmailCommseqStepLogsResponse](docs/EmailCommseqStepLogsResponse.md)
 - [UltracartClient::EmailCommseqWebhookSendTestRequest](docs/EmailCommseqWebhookSendTestRequest.md)
 - [UltracartClient::EmailCommseqsResponse](docs/EmailCommseqsResponse.md)
 - [UltracartClient::EmailCustomer](docs/EmailCustomer.md)
 - [UltracartClient::EmailCustomerEditorUrlResponse](docs/EmailCustomerEditorUrlResponse.md)
 - [UltracartClient::EmailCustomersResponse](docs/EmailCustomersResponse.md)
 - [UltracartClient::EmailDashboardActivity](docs/EmailDashboardActivity.md)
 - [UltracartClient::EmailDashboardActivityResponse](docs/EmailDashboardActivityResponse.md)
 - [UltracartClient::EmailDashboardStatsResponse](docs/EmailDashboardStatsResponse.md)
 - [UltracartClient::EmailDomain](docs/EmailDomain.md)
 - [UltracartClient::EmailEditorTokenResponse](docs/EmailEditorTokenResponse.md)
 - [UltracartClient::EmailFlow](docs/EmailFlow.md)
 - [UltracartClient::EmailFlowBackPopulateRequest](docs/EmailFlowBackPopulateRequest.md)
 - [UltracartClient::EmailFlowBackPopulateResponse](docs/EmailFlowBackPopulateResponse.md)
 - [UltracartClient::EmailFlowFolder](docs/EmailFlowFolder.md)
 - [UltracartClient::EmailFlowFolderResponse](docs/EmailFlowFolderResponse.md)
 - [UltracartClient::EmailFlowFoldersResponse](docs/EmailFlowFoldersResponse.md)
 - [UltracartClient::EmailFlowResponse](docs/EmailFlowResponse.md)
 - [UltracartClient::EmailFlowsResponse](docs/EmailFlowsResponse.md)
 - [UltracartClient::EmailGlobalSettings](docs/EmailGlobalSettings.md)
 - [UltracartClient::EmailGlobalSettingsResponse](docs/EmailGlobalSettingsResponse.md)
 - [UltracartClient::EmailGlobalUnsubscribeRequest](docs/EmailGlobalUnsubscribeRequest.md)
 - [UltracartClient::EmailGlobalUnsubscribeResponse](docs/EmailGlobalUnsubscribeResponse.md)
 - [UltracartClient::EmailHistogramPropertyNamesResponse](docs/EmailHistogramPropertyNamesResponse.md)
 - [UltracartClient::EmailHistogramPropertyValuesResponse](docs/EmailHistogramPropertyValuesResponse.md)
 - [UltracartClient::EmailList](docs/EmailList.md)
 - [UltracartClient::EmailListArchiveResponse](docs/EmailListArchiveResponse.md)
 - [UltracartClient::EmailListCustomer](docs/EmailListCustomer.md)
 - [UltracartClient::EmailListCustomersResponse](docs/EmailListCustomersResponse.md)
 - [UltracartClient::EmailListResponse](docs/EmailListResponse.md)
 - [UltracartClient::EmailListSegmentFolder](docs/EmailListSegmentFolder.md)
 - [UltracartClient::EmailListSegmentFolderResponse](docs/EmailListSegmentFolderResponse.md)
 - [UltracartClient::EmailListSegmentFoldersResponse](docs/EmailListSegmentFoldersResponse.md)
 - [UltracartClient::EmailListSegmentMembership](docs/EmailListSegmentMembership.md)
 - [UltracartClient::EmailListSegmentUsedBy](docs/EmailListSegmentUsedBy.md)
 - [UltracartClient::EmailListSubscribeResponse](docs/EmailListSubscribeResponse.md)
 - [UltracartClient::EmailListsResponse](docs/EmailListsResponse.md)
 - [UltracartClient::EmailOrder](docs/EmailOrder.md)
 - [UltracartClient::EmailOrdersResponse](docs/EmailOrdersResponse.md)
 - [UltracartClient::EmailPerformance](docs/EmailPerformance.md)
 - [UltracartClient::EmailPerformanceCustomerHistogram](docs/EmailPerformanceCustomerHistogram.md)
 - [UltracartClient::EmailPerformanceCustomerHistogramPeriod](docs/EmailPerformanceCustomerHistogramPeriod.md)
 - [UltracartClient::EmailPerformanceDaily](docs/EmailPerformanceDaily.md)
 - [UltracartClient::EmailPerformanceResponse](docs/EmailPerformanceResponse.md)
 - [UltracartClient::EmailPlan](docs/EmailPlan.md)
 - [UltracartClient::EmailPlanAdditional](docs/EmailPlanAdditional.md)
 - [UltracartClient::EmailPlanResponse](docs/EmailPlanResponse.md)
 - [UltracartClient::EmailPostcardStat](docs/EmailPostcardStat.md)
 - [UltracartClient::EmailSegment](docs/EmailSegment.md)
 - [UltracartClient::EmailSegmentArchiveResponse](docs/EmailSegmentArchiveResponse.md)
 - [UltracartClient::EmailSegmentCustomer](docs/EmailSegmentCustomer.md)
 - [UltracartClient::EmailSegmentCustomersResponse](docs/EmailSegmentCustomersResponse.md)
 - [UltracartClient::EmailSegmentDownloadPrepareResponse](docs/EmailSegmentDownloadPrepareResponse.md)
 - [UltracartClient::EmailSegmentResponse](docs/EmailSegmentResponse.md)
 - [UltracartClient::EmailSegmentsResponse](docs/EmailSegmentsResponse.md)
 - [UltracartClient::EmailSendingDomainResponse](docs/EmailSendingDomainResponse.md)
 - [UltracartClient::EmailSendingDomainsResponse](docs/EmailSendingDomainsResponse.md)
 - [UltracartClient::EmailSettings](docs/EmailSettings.md)
 - [UltracartClient::EmailSettingsResponse](docs/EmailSettingsResponse.md)
 - [UltracartClient::EmailStat](docs/EmailStat.md)
 - [UltracartClient::EmailStatPostcardSummaryRequest](docs/EmailStatPostcardSummaryRequest.md)
 - [UltracartClient::EmailStatPostcardSummaryResponse](docs/EmailStatPostcardSummaryResponse.md)
 - [UltracartClient::EmailStatSummaryRequest](docs/EmailStatSummaryRequest.md)
 - [UltracartClient::EmailStatSummaryResponse](docs/EmailStatSummaryResponse.md)
 - [UltracartClient::EmailStepStat](docs/EmailStepStat.md)
 - [UltracartClient::EmailStepStatRequest](docs/EmailStepStatRequest.md)
 - [UltracartClient::EmailStepStatResponse](docs/EmailStepStatResponse.md)
 - [UltracartClient::EmailStepWaitingRequest](docs/EmailStepWaitingRequest.md)
 - [UltracartClient::EmailStepWaitingResponse](docs/EmailStepWaitingResponse.md)
 - [UltracartClient::EmailTemplate](docs/EmailTemplate.md)
 - [UltracartClient::EmailTemplatesResponse](docs/EmailTemplatesResponse.md)
 - [UltracartClient::EmailThirdPartyList](docs/EmailThirdPartyList.md)
 - [UltracartClient::EmailThirdPartyListImportRequest](docs/EmailThirdPartyListImportRequest.md)
 - [UltracartClient::EmailThirdPartyProvider](docs/EmailThirdPartyProvider.md)
 - [UltracartClient::EmailThirdPartyProvidersResponse](docs/EmailThirdPartyProvidersResponse.md)
 - [UltracartClient::EmailVerifyTokenRequest](docs/EmailVerifyTokenRequest.md)
 - [UltracartClient::EmailVerifyTokenResponse](docs/EmailVerifyTokenResponse.md)
 - [UltracartClient::EmailVerifyTokenValidateRequest](docs/EmailVerifyTokenValidateRequest.md)
 - [UltracartClient::EmailVerifyTokenValidateResponse](docs/EmailVerifyTokenValidateResponse.md)
 - [UltracartClient::EmailWebhookEditorValuesResponse](docs/EmailWebhookEditorValuesResponse.md)
 - [UltracartClient::Error](docs/Error.md)
 - [UltracartClient::ErrorResponse](docs/ErrorResponse.md)
 - [UltracartClient::Experiment](docs/Experiment.md)
 - [UltracartClient::ExperimentResponse](docs/ExperimentResponse.md)
 - [UltracartClient::ExperimentVariation](docs/ExperimentVariation.md)
 - [UltracartClient::ExperimentsResponse](docs/ExperimentsResponse.md)
 - [UltracartClient::FulfillmentInventory](docs/FulfillmentInventory.md)
 - [UltracartClient::FulfillmentShipment](docs/FulfillmentShipment.md)
 - [UltracartClient::GeoPoint](docs/GeoPoint.md)
 - [UltracartClient::GeocodeRequest](docs/GeocodeRequest.md)
 - [UltracartClient::GeocodeResponse](docs/GeocodeResponse.md)
 - [UltracartClient::Group](docs/Group.md)
 - [UltracartClient::GroupResponse](docs/GroupResponse.md)
 - [UltracartClient::GroupUserMembership](docs/GroupUserMembership.md)
 - [UltracartClient::GroupsResponse](docs/GroupsResponse.md)
 - [UltracartClient::HTTPHeader](docs/HTTPHeader.md)
 - [UltracartClient::IntegrationLog](docs/IntegrationLog.md)
 - [UltracartClient::IntegrationLogFile](docs/IntegrationLogFile.md)
 - [UltracartClient::IntegrationLogLog](docs/IntegrationLogLog.md)
 - [UltracartClient::IntegrationLogQueryFilterValues](docs/IntegrationLogQueryFilterValues.md)
 - [UltracartClient::IntegrationLogQueryRequest](docs/IntegrationLogQueryRequest.md)
 - [UltracartClient::IntegrationLogQueryResponse](docs/IntegrationLogQueryResponse.md)
 - [UltracartClient::IntegrationLogResponse](docs/IntegrationLogResponse.md)
 - [UltracartClient::IntegrationLogSummary](docs/IntegrationLogSummary.md)
 - [UltracartClient::IntegrationLogSummaryQueryRequest](docs/IntegrationLogSummaryQueryRequest.md)
 - [UltracartClient::IntegrationLogSummaryQueryResponse](docs/IntegrationLogSummaryQueryResponse.md)
 - [UltracartClient::Item](docs/Item.md)
 - [UltracartClient::ItemAccounting](docs/ItemAccounting.md)
 - [UltracartClient::ItemAmember](docs/ItemAmember.md)
 - [UltracartClient::ItemAutoOrder](docs/ItemAutoOrder.md)
 - [UltracartClient::ItemAutoOrderStep](docs/ItemAutoOrderStep.md)
 - [UltracartClient::ItemAutoOrderStepArbitraryUnitCostSchedule](docs/ItemAutoOrderStepArbitraryUnitCostSchedule.md)
 - [UltracartClient::ItemAutoOrderStepGrandfatherPricing](docs/ItemAutoOrderStepGrandfatherPricing.md)
 - [UltracartClient::ItemCCBill](docs/ItemCCBill.md)
 - [UltracartClient::ItemChannelPartnerMapping](docs/ItemChannelPartnerMapping.md)
 - [UltracartClient::ItemChargeback](docs/ItemChargeback.md)
 - [UltracartClient::ItemChargebackAddendum](docs/ItemChargebackAddendum.md)
 - [UltracartClient::ItemChargebackAdjustmentRequest](docs/ItemChargebackAdjustmentRequest.md)
 - [UltracartClient::ItemCheckout](docs/ItemCheckout.md)
 - [UltracartClient::ItemContent](docs/ItemContent.md)
 - [UltracartClient::ItemContentAssignment](docs/ItemContentAssignment.md)
 - [UltracartClient::ItemContentAttribute](docs/ItemContentAttribute.md)
 - [UltracartClient::ItemContentMultimedia](docs/ItemContentMultimedia.md)
 - [UltracartClient::ItemContentMultimediaThumbnail](docs/ItemContentMultimediaThumbnail.md)
 - [UltracartClient::ItemDigitalDelivery](docs/ItemDigitalDelivery.md)
 - [UltracartClient::ItemDigitalItem](docs/ItemDigitalItem.md)
 - [UltracartClient::ItemEbay](docs/ItemEbay.md)
 - [UltracartClient::ItemEbayCategorySpecific](docs/ItemEbayCategorySpecific.md)
 - [UltracartClient::ItemEbayMarketListing](docs/ItemEbayMarketListing.md)
 - [UltracartClient::ItemEbayMarketPlaceAnalysis](docs/ItemEbayMarketPlaceAnalysis.md)
 - [UltracartClient::ItemEmailNotifications](docs/ItemEmailNotifications.md)
 - [UltracartClient::ItemEnrollment123](docs/ItemEnrollment123.md)
 - [UltracartClient::ItemGiftCertificate](docs/ItemGiftCertificate.md)
 - [UltracartClient::ItemGoogleProductSearch](docs/ItemGoogleProductSearch.md)
 - [UltracartClient::ItemIdentifiers](docs/ItemIdentifiers.md)
 - [UltracartClient::ItemInstantPaymentNotification](docs/ItemInstantPaymentNotification.md)
 - [UltracartClient::ItemInstantPaymentNotifications](docs/ItemInstantPaymentNotifications.md)
 - [UltracartClient::ItemInternal](docs/ItemInternal.md)
 - [UltracartClient::ItemKitComponent](docs/ItemKitComponent.md)
 - [UltracartClient::ItemKitDefinition](docs/ItemKitDefinition.md)
 - [UltracartClient::ItemOption](docs/ItemOption.md)
 - [UltracartClient::ItemOptionValue](docs/ItemOptionValue.md)
 - [UltracartClient::ItemOptionValueAdditionalItem](docs/ItemOptionValueAdditionalItem.md)
 - [UltracartClient::ItemOptionValueDigitalItem](docs/ItemOptionValueDigitalItem.md)
 - [UltracartClient::ItemPaymentProcessing](docs/ItemPaymentProcessing.md)
 - [UltracartClient::ItemPhysical](docs/ItemPhysical.md)
 - [UltracartClient::ItemPricing](docs/ItemPricing.md)
 - [UltracartClient::ItemPricingTier](docs/ItemPricingTier.md)
 - [UltracartClient::ItemPricingTierDiscount](docs/ItemPricingTierDiscount.md)
 - [UltracartClient::ItemPricingTierLimit](docs/ItemPricingTierLimit.md)
 - [UltracartClient::ItemProperty](docs/ItemProperty.md)
 - [UltracartClient::ItemRealtimePricing](docs/ItemRealtimePricing.md)
 - [UltracartClient::ItemRelated](docs/ItemRelated.md)
 - [UltracartClient::ItemRelatedItem](docs/ItemRelatedItem.md)
 - [UltracartClient::ItemReporting](docs/ItemReporting.md)
 - [UltracartClient::ItemResponse](docs/ItemResponse.md)
 - [UltracartClient::ItemRestriction](docs/ItemRestriction.md)
 - [UltracartClient::ItemRestrictionItem](docs/ItemRestrictionItem.md)
 - [UltracartClient::ItemRevguard](docs/ItemRevguard.md)
 - [UltracartClient::ItemReviews](docs/ItemReviews.md)
 - [UltracartClient::ItemSalesforce](docs/ItemSalesforce.md)
 - [UltracartClient::ItemShipping](docs/ItemShipping.md)
 - [UltracartClient::ItemShippingCase](docs/ItemShippingCase.md)
 - [UltracartClient::ItemShippingDestinationMarkup](docs/ItemShippingDestinationMarkup.md)
 - [UltracartClient::ItemShippingDestinationRestriction](docs/ItemShippingDestinationRestriction.md)
 - [UltracartClient::ItemShippingDistributionCenter](docs/ItemShippingDistributionCenter.md)
 - [UltracartClient::ItemShippingMethod](docs/ItemShippingMethod.md)
 - [UltracartClient::ItemShippingPackageRequirement](docs/ItemShippingPackageRequirement.md)
 - [UltracartClient::ItemTag](docs/ItemTag.md)
 - [UltracartClient::ItemTags](docs/ItemTags.md)
 - [UltracartClient::ItemTax](docs/ItemTax.md)
 - [UltracartClient::ItemTaxExemption](docs/ItemTaxExemption.md)
 - [UltracartClient::ItemThirdPartyEmailMarketing](docs/ItemThirdPartyEmailMarketing.md)
 - [UltracartClient::ItemVariantItem](docs/ItemVariantItem.md)
 - [UltracartClient::ItemVariation](docs/ItemVariation.md)
 - [UltracartClient::ItemVariationOption](docs/ItemVariationOption.md)
 - [UltracartClient::ItemWishlistMember](docs/ItemWishlistMember.md)
 - [UltracartClient::ItemsRequest](docs/ItemsRequest.md)
 - [UltracartClient::ItemsResponse](docs/ItemsResponse.md)
 - [UltracartClient::KeyValue](docs/KeyValue.md)
 - [UltracartClient::LibraryFilterValues](docs/LibraryFilterValues.md)
 - [UltracartClient::LibraryFilterValuesResponse](docs/LibraryFilterValuesResponse.md)
 - [UltracartClient::LibraryItem](docs/LibraryItem.md)
 - [UltracartClient::LibraryItemAccount](docs/LibraryItemAccount.md)
 - [UltracartClient::LibraryItemAsset](docs/LibraryItemAsset.md)
 - [UltracartClient::LibraryItemAttribute](docs/LibraryItemAttribute.md)
 - [UltracartClient::LibraryItemEmail](docs/LibraryItemEmail.md)
 - [UltracartClient::LibraryItemPublishedMeta](docs/LibraryItemPublishedMeta.md)
 - [UltracartClient::LibraryItemPurchasedMeta](docs/LibraryItemPurchasedMeta.md)
 - [UltracartClient::LibraryItemQuery](docs/LibraryItemQuery.md)
 - [UltracartClient::LibraryItemResponse](docs/LibraryItemResponse.md)
 - [UltracartClient::LibraryItemScreenshot](docs/LibraryItemScreenshot.md)
 - [UltracartClient::LibraryItemsResponse](docs/LibraryItemsResponse.md)
 - [UltracartClient::LinkedAccount](docs/LinkedAccount.md)
 - [UltracartClient::ListSegmentMembership](docs/ListSegmentMembership.md)
 - [UltracartClient::LookupRequest](docs/LookupRequest.md)
 - [UltracartClient::LookupResponse](docs/LookupResponse.md)
 - [UltracartClient::Metric](docs/Metric.md)
 - [UltracartClient::Notification](docs/Notification.md)
 - [UltracartClient::OauthRevokeSuccessResponse](docs/OauthRevokeSuccessResponse.md)
 - [UltracartClient::OauthTokenResponse](docs/OauthTokenResponse.md)
 - [UltracartClient::Order](docs/Order.md)
 - [UltracartClient::OrderAffiliate](docs/OrderAffiliate.md)
 - [UltracartClient::OrderAffiliateLedger](docs/OrderAffiliateLedger.md)
 - [UltracartClient::OrderAutoOrder](docs/OrderAutoOrder.md)
 - [UltracartClient::OrderBilling](docs/OrderBilling.md)
 - [UltracartClient::OrderBuysafe](docs/OrderBuysafe.md)
 - [UltracartClient::OrderByTokenQuery](docs/OrderByTokenQuery.md)
 - [UltracartClient::OrderChannelPartner](docs/OrderChannelPartner.md)
 - [UltracartClient::OrderCheckout](docs/OrderCheckout.md)
 - [UltracartClient::OrderCoupon](docs/OrderCoupon.md)
 - [UltracartClient::OrderDigitalItem](docs/OrderDigitalItem.md)
 - [UltracartClient::OrderDigitalOrder](docs/OrderDigitalOrder.md)
 - [UltracartClient::OrderEdi](docs/OrderEdi.md)
 - [UltracartClient::OrderFormat](docs/OrderFormat.md)
 - [UltracartClient::OrderFormatResponse](docs/OrderFormatResponse.md)
 - [UltracartClient::OrderFraudScore](docs/OrderFraudScore.md)
 - [UltracartClient::OrderGift](docs/OrderGift.md)
 - [UltracartClient::OrderGiftCertificate](docs/OrderGiftCertificate.md)
 - [UltracartClient::OrderInternal](docs/OrderInternal.md)
 - [UltracartClient::OrderItem](docs/OrderItem.md)
 - [UltracartClient::OrderItemEdi](docs/OrderItemEdi.md)
 - [UltracartClient::OrderItemEdiIdentification](docs/OrderItemEdiIdentification.md)
 - [UltracartClient::OrderItemEdiLot](docs/OrderItemEdiLot.md)
 - [UltracartClient::OrderItemOption](docs/OrderItemOption.md)
 - [UltracartClient::OrderItemOptionFileAttachment](docs/OrderItemOptionFileAttachment.md)
 - [UltracartClient::OrderItemProperty](docs/OrderItemProperty.md)
 - [UltracartClient::OrderItemTag](docs/OrderItemTag.md)
 - [UltracartClient::OrderLinkedShipment](docs/OrderLinkedShipment.md)
 - [UltracartClient::OrderMarketing](docs/OrderMarketing.md)
 - [UltracartClient::OrderPayment](docs/OrderPayment.md)
 - [UltracartClient::OrderPaymentCheck](docs/OrderPaymentCheck.md)
 - [UltracartClient::OrderPaymentCreditCard](docs/OrderPaymentCreditCard.md)
 - [UltracartClient::OrderPaymentECheck](docs/OrderPaymentECheck.md)
 - [UltracartClient::OrderPaymentInsurance](docs/OrderPaymentInsurance.md)
 - [UltracartClient::OrderPaymentPurchaseOrder](docs/OrderPaymentPurchaseOrder.md)
 - [UltracartClient::OrderPaymentTransaction](docs/OrderPaymentTransaction.md)
 - [UltracartClient::OrderPaymentTransactionDetail](docs/OrderPaymentTransactionDetail.md)
 - [UltracartClient::OrderProcessPaymentRequest](docs/OrderProcessPaymentRequest.md)
 - [UltracartClient::OrderProcessPaymentResponse](docs/OrderProcessPaymentResponse.md)
 - [UltracartClient::OrderProperty](docs/OrderProperty.md)
 - [UltracartClient::OrderQuery](docs/OrderQuery.md)
 - [UltracartClient::OrderQueryBatch](docs/OrderQueryBatch.md)
 - [UltracartClient::OrderQuote](docs/OrderQuote.md)
 - [UltracartClient::OrderReplacement](docs/OrderReplacement.md)
 - [UltracartClient::OrderReplacementItem](docs/OrderReplacementItem.md)
 - [UltracartClient::OrderReplacementResponse](docs/OrderReplacementResponse.md)
 - [UltracartClient::OrderResponse](docs/OrderResponse.md)
 - [UltracartClient::OrderSalesforce](docs/OrderSalesforce.md)
 - [UltracartClient::OrderShipping](docs/OrderShipping.md)
 - [UltracartClient::OrderSummary](docs/OrderSummary.md)
 - [UltracartClient::OrderTag](docs/OrderTag.md)
 - [UltracartClient::OrderTaxes](docs/OrderTaxes.md)
 - [UltracartClient::OrderTokenResponse](docs/OrderTokenResponse.md)
 - [UltracartClient::OrderTrackingNumberDetail](docs/OrderTrackingNumberDetail.md)
 - [UltracartClient::OrderTrackingNumberDetails](docs/OrderTrackingNumberDetails.md)
 - [UltracartClient::OrdersResponse](docs/OrdersResponse.md)
 - [UltracartClient::PaymentsConfiguration](docs/PaymentsConfiguration.md)
 - [UltracartClient::PaymentsConfigurationAffirm](docs/PaymentsConfigurationAffirm.md)
 - [UltracartClient::PaymentsConfigurationAmazon](docs/PaymentsConfigurationAmazon.md)
 - [UltracartClient::PaymentsConfigurationCOD](docs/PaymentsConfigurationCOD.md)
 - [UltracartClient::PaymentsConfigurationCash](docs/PaymentsConfigurationCash.md)
 - [UltracartClient::PaymentsConfigurationCheck](docs/PaymentsConfigurationCheck.md)
 - [UltracartClient::PaymentsConfigurationCreditCard](docs/PaymentsConfigurationCreditCard.md)
 - [UltracartClient::PaymentsConfigurationCreditCardType](docs/PaymentsConfigurationCreditCardType.md)
 - [UltracartClient::PaymentsConfigurationEcheck](docs/PaymentsConfigurationEcheck.md)
 - [UltracartClient::PaymentsConfigurationInsurance](docs/PaymentsConfigurationInsurance.md)
 - [UltracartClient::PaymentsConfigurationLoanHero](docs/PaymentsConfigurationLoanHero.md)
 - [UltracartClient::PaymentsConfigurationMoneyOrder](docs/PaymentsConfigurationMoneyOrder.md)
 - [UltracartClient::PaymentsConfigurationPayPal](docs/PaymentsConfigurationPayPal.md)
 - [UltracartClient::PaymentsConfigurationPurchaseOrder](docs/PaymentsConfigurationPurchaseOrder.md)
 - [UltracartClient::PaymentsConfigurationQuoteRequest](docs/PaymentsConfigurationQuoteRequest.md)
 - [UltracartClient::PaymentsConfigurationResponse](docs/PaymentsConfigurationResponse.md)
 - [UltracartClient::PaymentsConfigurationRestrictions](docs/PaymentsConfigurationRestrictions.md)
 - [UltracartClient::PaymentsConfigurationRestrictionsTheme](docs/PaymentsConfigurationRestrictionsTheme.md)
 - [UltracartClient::PaymentsConfigurationSezzle](docs/PaymentsConfigurationSezzle.md)
 - [UltracartClient::PaymentsConfigurationTestMethod](docs/PaymentsConfigurationTestMethod.md)
 - [UltracartClient::PaymentsConfigurationWePay](docs/PaymentsConfigurationWePay.md)
 - [UltracartClient::PaymentsConfigurationWireTransfer](docs/PaymentsConfigurationWireTransfer.md)
 - [UltracartClient::PaymentsThemeTransactionType](docs/PaymentsThemeTransactionType.md)
 - [UltracartClient::PaymentsWepayEnroll](docs/PaymentsWepayEnroll.md)
 - [UltracartClient::Permission](docs/Permission.md)
 - [UltracartClient::PricingTier](docs/PricingTier.md)
 - [UltracartClient::PricingTierNotification](docs/PricingTierNotification.md)
 - [UltracartClient::PricingTiersResponse](docs/PricingTiersResponse.md)
 - [UltracartClient::Property](docs/Property.md)
 - [UltracartClient::PublishLibraryItemRequest](docs/PublishLibraryItemRequest.md)
 - [UltracartClient::RegisterAffiliateClickRequest](docs/RegisterAffiliateClickRequest.md)
 - [UltracartClient::RegisterAffiliateClickResponse](docs/RegisterAffiliateClickResponse.md)
 - [UltracartClient::ResponseMetadata](docs/ResponseMetadata.md)
 - [UltracartClient::ResultSet](docs/ResultSet.md)
 - [UltracartClient::RotatingTransactionGateway](docs/RotatingTransactionGateway.md)
 - [UltracartClient::RotatingTransactionGatewayResponse](docs/RotatingTransactionGatewayResponse.md)
 - [UltracartClient::RotatingTransactionGatewaysResponse](docs/RotatingTransactionGatewaysResponse.md)
 - [UltracartClient::RtgCurrency](docs/RtgCurrency.md)
 - [UltracartClient::RtgDayOfMonthRestriction](docs/RtgDayOfMonthRestriction.md)
 - [UltracartClient::RtgDayOfWeekRestriction](docs/RtgDayOfWeekRestriction.md)
 - [UltracartClient::RtgSummaryGateway](docs/RtgSummaryGateway.md)
 - [UltracartClient::RtgSummaryResponse](docs/RtgSummaryResponse.md)
 - [UltracartClient::RtgThemeRestriction](docs/RtgThemeRestriction.md)
 - [UltracartClient::ScreenRecording](docs/ScreenRecording.md)
 - [UltracartClient::ScreenRecordingAdPlatform](docs/ScreenRecordingAdPlatform.md)
 - [UltracartClient::ScreenRecordingFilter](docs/ScreenRecordingFilter.md)
 - [UltracartClient::ScreenRecordingFilterGeoDistance](docs/ScreenRecordingFilterGeoDistance.md)
 - [UltracartClient::ScreenRecordingFilterIpSearch](docs/ScreenRecordingFilterIpSearch.md)
 - [UltracartClient::ScreenRecordingFilterPageView](docs/ScreenRecordingFilterPageView.md)
 - [UltracartClient::ScreenRecordingFilterPageViewEvent](docs/ScreenRecordingFilterPageViewEvent.md)
 - [UltracartClient::ScreenRecordingFilterPageViewEventParam](docs/ScreenRecordingFilterPageViewEventParam.md)
 - [UltracartClient::ScreenRecordingFilterPageViewParam](docs/ScreenRecordingFilterPageViewParam.md)
 - [UltracartClient::ScreenRecordingFilterPageViewReferrerParam](docs/ScreenRecordingFilterPageViewReferrerParam.md)
 - [UltracartClient::ScreenRecordingFilterRangeBigDecimal](docs/ScreenRecordingFilterRangeBigDecimal.md)
 - [UltracartClient::ScreenRecordingFilterRangeDate](docs/ScreenRecordingFilterRangeDate.md)
 - [UltracartClient::ScreenRecordingFilterRangeInteger](docs/ScreenRecordingFilterRangeInteger.md)
 - [UltracartClient::ScreenRecordingFilterStringSearch](docs/ScreenRecordingFilterStringSearch.md)
 - [UltracartClient::ScreenRecordingFilterValues](docs/ScreenRecordingFilterValues.md)
 - [UltracartClient::ScreenRecordingFilterValuesEvent](docs/ScreenRecordingFilterValuesEvent.md)
 - [UltracartClient::ScreenRecordingFilterValuesEventParams](docs/ScreenRecordingFilterValuesEventParams.md)
 - [UltracartClient::ScreenRecordingFilterValuesPageParam](docs/ScreenRecordingFilterValuesPageParam.md)
 - [UltracartClient::ScreenRecordingFilterValuesPageView](docs/ScreenRecordingFilterValuesPageView.md)
 - [UltracartClient::ScreenRecordingHeatmap](docs/ScreenRecordingHeatmap.md)
 - [UltracartClient::ScreenRecordingHeatmapIndexRequest](docs/ScreenRecordingHeatmapIndexRequest.md)
 - [UltracartClient::ScreenRecordingHeatmapIndexResponse](docs/ScreenRecordingHeatmapIndexResponse.md)
 - [UltracartClient::ScreenRecordingHeatmapRequest](docs/ScreenRecordingHeatmapRequest.md)
 - [UltracartClient::ScreenRecordingHeatmapReset](docs/ScreenRecordingHeatmapReset.md)
 - [UltracartClient::ScreenRecordingHeatmapResponse](docs/ScreenRecordingHeatmapResponse.md)
 - [UltracartClient::ScreenRecordingHeatmapUrl](docs/ScreenRecordingHeatmapUrl.md)
 - [UltracartClient::ScreenRecordingMerchantNotesRequest](docs/ScreenRecordingMerchantNotesRequest.md)
 - [UltracartClient::ScreenRecordingMultifield](docs/ScreenRecordingMultifield.md)
 - [UltracartClient::ScreenRecordingPageView](docs/ScreenRecordingPageView.md)
 - [UltracartClient::ScreenRecordingPageViewDataResponse](docs/ScreenRecordingPageViewDataResponse.md)
 - [UltracartClient::ScreenRecordingPageViewEvent](docs/ScreenRecordingPageViewEvent.md)
 - [UltracartClient::ScreenRecordingPageViewEventParameter](docs/ScreenRecordingPageViewEventParameter.md)
 - [UltracartClient::ScreenRecordingPageViewParameter](docs/ScreenRecordingPageViewParameter.md)
 - [UltracartClient::ScreenRecordingQueryRequest](docs/ScreenRecordingQueryRequest.md)
 - [UltracartClient::ScreenRecordingQueryResponse](docs/ScreenRecordingQueryResponse.md)
 - [UltracartClient::ScreenRecordingResponse](docs/ScreenRecordingResponse.md)
 - [UltracartClient::ScreenRecordingSegment](docs/ScreenRecordingSegment.md)
 - [UltracartClient::ScreenRecordingSegmentResponse](docs/ScreenRecordingSegmentResponse.md)
 - [UltracartClient::ScreenRecordingSegmentsResponse](docs/ScreenRecordingSegmentsResponse.md)
 - [UltracartClient::ScreenRecordingSettings](docs/ScreenRecordingSettings.md)
 - [UltracartClient::ScreenRecordingSettingsResponse](docs/ScreenRecordingSettingsResponse.md)
 - [UltracartClient::ScreenRecordingStoreFront](docs/ScreenRecordingStoreFront.md)
 - [UltracartClient::ScreenRecordingTagsRequest](docs/ScreenRecordingTagsRequest.md)
 - [UltracartClient::ScreenRecordingTagsResponse](docs/ScreenRecordingTagsResponse.md)
 - [UltracartClient::ScreenRecordingUserAgent](docs/ScreenRecordingUserAgent.md)
 - [UltracartClient::ScreenRecordingUserAgentDevice](docs/ScreenRecordingUserAgentDevice.md)
 - [UltracartClient::ScreenRecordingUserAgentOS](docs/ScreenRecordingUserAgentOS.md)
 - [UltracartClient::ScreenRecordingUserProperty](docs/ScreenRecordingUserProperty.md)
 - [UltracartClient::ScreenshotsResponse](docs/ScreenshotsResponse.md)
 - [UltracartClient::SelfConfig](docs/SelfConfig.md)
 - [UltracartClient::SimpleValue](docs/SimpleValue.md)
 - [UltracartClient::SingleSignOnAuthorizeRequest](docs/SingleSignOnAuthorizeRequest.md)
 - [UltracartClient::SingleSignOnAuthorizeResponse](docs/SingleSignOnAuthorizeResponse.md)
 - [UltracartClient::SingleSignOnTokenRequest](docs/SingleSignOnTokenRequest.md)
 - [UltracartClient::SingleSignOnTokenResponse](docs/SingleSignOnTokenResponse.md)
 - [UltracartClient::SovosConfig](docs/SovosConfig.md)
 - [UltracartClient::StateProvince](docs/StateProvince.md)
 - [UltracartClient::StepWaiting](docs/StepWaiting.md)
 - [UltracartClient::StripeConnectResponse](docs/StripeConnectResponse.md)
 - [UltracartClient::TaxCity](docs/TaxCity.md)
 - [UltracartClient::TaxCountry](docs/TaxCountry.md)
 - [UltracartClient::TaxCountryCode](docs/TaxCountryCode.md)
 - [UltracartClient::TaxCounty](docs/TaxCounty.md)
 - [UltracartClient::TaxJarConfig](docs/TaxJarConfig.md)
 - [UltracartClient::TaxPostalCode](docs/TaxPostalCode.md)
 - [UltracartClient::TaxProviderActivateResult](docs/TaxProviderActivateResult.md)
 - [UltracartClient::TaxProviderAvalara](docs/TaxProviderAvalara.md)
 - [UltracartClient::TaxProviderAvalaraCompaniesResult](docs/TaxProviderAvalaraCompaniesResult.md)
 - [UltracartClient::TaxProviderAvalaraCompany](docs/TaxProviderAvalaraCompany.md)
 - [UltracartClient::TaxProviderSelf](docs/TaxProviderSelf.md)
 - [UltracartClient::TaxProviderSelfCountriesResponse](docs/TaxProviderSelfCountriesResponse.md)
 - [UltracartClient::TaxProviderSelfRegionsResponse](docs/TaxProviderSelfRegionsResponse.md)
 - [UltracartClient::TaxProviderSovos](docs/TaxProviderSovos.md)
 - [UltracartClient::TaxProviderTaxJar](docs/TaxProviderTaxJar.md)
 - [UltracartClient::TaxProviderTestResult](docs/TaxProviderTestResult.md)
 - [UltracartClient::TaxProviderUltraCart](docs/TaxProviderUltraCart.md)
 - [UltracartClient::TaxProviderUltraCartState](docs/TaxProviderUltraCartState.md)
 - [UltracartClient::TaxProvidersResponse](docs/TaxProvidersResponse.md)
 - [UltracartClient::TaxState](docs/TaxState.md)
 - [UltracartClient::TaxStateCode](docs/TaxStateCode.md)
 - [UltracartClient::TempMultimedia](docs/TempMultimedia.md)
 - [UltracartClient::TempMultimediaResponse](docs/TempMultimediaResponse.md)
 - [UltracartClient::ThumbnailParametersRequest](docs/ThumbnailParametersRequest.md)
 - [UltracartClient::ThumbnailParametersResponse](docs/ThumbnailParametersResponse.md)
 - [UltracartClient::TransactionEmail](docs/TransactionEmail.md)
 - [UltracartClient::TransactionEmailListResponse](docs/TransactionEmailListResponse.md)
 - [UltracartClient::TransactionEmailOption](docs/TransactionEmailOption.md)
 - [UltracartClient::TransactionEmailResponse](docs/TransactionEmailResponse.md)
 - [UltracartClient::TransactionGateway](docs/TransactionGateway.md)
 - [UltracartClient::TransactionGatewaysRequest](docs/TransactionGatewaysRequest.md)
 - [UltracartClient::TransactionGatewaysResponse](docs/TransactionGatewaysResponse.md)
 - [UltracartClient::UltraCartConfig](docs/UltraCartConfig.md)
 - [UltracartClient::UploadCouponCodesRequest](docs/UploadCouponCodesRequest.md)
 - [UltracartClient::UploadCouponCodesResponse](docs/UploadCouponCodesResponse.md)
 - [UltracartClient::User](docs/User.md)
 - [UltracartClient::UserGroupMembership](docs/UserGroupMembership.md)
 - [UltracartClient::UserLogin](docs/UserLogin.md)
 - [UltracartClient::UserLoginsResponse](docs/UserLoginsResponse.md)
 - [UltracartClient::UserResponse](docs/UserResponse.md)
 - [UltracartClient::UsersResponse](docs/UsersResponse.md)
 - [UltracartClient::VerificationRecord](docs/VerificationRecord.md)
 - [UltracartClient::Warning](docs/Warning.md)
 - [UltracartClient::Webhook](docs/Webhook.md)
 - [UltracartClient::WebhookEventCategory](docs/WebhookEventCategory.md)
 - [UltracartClient::WebhookEventSubscription](docs/WebhookEventSubscription.md)
 - [UltracartClient::WebhookLog](docs/WebhookLog.md)
 - [UltracartClient::WebhookLogResponse](docs/WebhookLogResponse.md)
 - [UltracartClient::WebhookLogSummariesResponse](docs/WebhookLogSummariesResponse.md)
 - [UltracartClient::WebhookLogSummary](docs/WebhookLogSummary.md)
 - [UltracartClient::WebhookResponse](docs/WebhookResponse.md)
 - [UltracartClient::WebhookSampleRequest](docs/WebhookSampleRequest.md)
 - [UltracartClient::WebhookSampleRequestResponse](docs/WebhookSampleRequestResponse.md)
 - [UltracartClient::WebhooksResponse](docs/WebhooksResponse.md)
 - [UltracartClient::Weight](docs/Weight.md)


## Documentation for Authorization


### ultraCartBrowserApiKey

- **Type**: API key
- **API key parameter name**: x-ultracart-browser-key
- **Location**: HTTP header

### ultraCartOauth

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://secure.ultracart.com/rest/v2/oauth/authorize
- **Scopes**: 
  - affiliate_read: Allows you to read affiliate information.
  - affiliate_write: Allows you to write affiliate information.
  - auto_order_read: Allows you to read auto order information.
  - auto_order_write: Allows you to write auto order information.
  - chargeback_read: Allows you to read chargeback information.
  - chargeback_write: Allows you to write chargeback information.
  - checkout_read: Allows you to read checkout information.
  - checkout_write: Allows you to write checkout information.
  - configuration_read: Allows you to read configuration information.
  - configuration_write: Allows you to write configuration information.
  - coupon_read: Allows you to read coupon information.
  - coupon_write: Allows you to write coupon information.
  - customer_read: Allows you to read customer information.
  - customer_write: Allows you to write customer information.
  - fulfillment_read: Allows you to read fulfillment information.
  - fulfillment_write: Allows you to write fulfillment information.
  - integration_log_read: Allows you to read integration log information.
  - integration_log_write: Allows you to write integration log information.
  - order_read: Allows you to read order information.
  - order_write: Allows you to write order information.
  - item_read: Allows you to read item information.
  - item_write: Allows you to write item information.
  - storefront_read: Allows you to read storefront information.
  - storefront_write: Allows you to write storefront information.
  - tax_read: Allows you to read tax configuration information.
  - tax_write: Allows you to write tax configuration information.
  - webhook_read: Allows you to read webhook information.
  - webhook_write: Allows you to write webhook information.
  - ultrabooks_read: 1 of 2 required to use UltraBooks
  - ultrabooks_write: 2 of 2 required to use UltraBooks
  - user_read: Allows you to read user information.
  - user_write: Allows you to write user information.

### ultraCartSimpleApiKey

- **Type**: API key
- **API key parameter name**: x-ultracart-simple-key
- **Location**: HTTP header




# CHANGE LOG
Not every change is committed to every SDK.

| Version | Date | Comments |
| --: | :-: | --- |
| 3.6.11 | 09/13/2021 | fix for CouponApi, broke due to inadvertent parameter inclusion   | 
| 3.6.10 | 09/09/2021 | added constants for Google Shopping payment method (still in development)  | 
| 3.6.9 | 09/07/2021 | customer profile editor values have new list of state optional countries  | 
| 3.6.8 | 08/31/2021 | coupon query field to allow merchant code and description to be searched  | 
| 3.6.7 | 08/27/2021 | customer profile affiliate information now contains affiliate first and last name | 
| 3.6.6 | 08/26/2021 | configuration api - more field changes for UI | 
| 3.6.5 | 08/25/2021 | configuration api - removed some internal fields from sdk | 
| 3.6.4 | 08/24/2021 | configuration api - new payment method named insurance | 
| 3.6.1 | 08/23/2021 | configuration api - enum problems, also added order.item.tracking_number to support line item tracking numbers | 
| 3.6.0 | 08/19/2021 | coupon api - changed tieredAmountOffItem to support mulitple items | 
| 3.5.3 | 08/18/2021 | configuration api - added credit card rate to UltraCart Payments object | 
| 3.5.1 | 08/11/2021 | email webhook test method | 
| 3.5.0 | 08/11/2021 | RestOrderChannelPartner.store_completed was incorrectly defaulting to true | 
| 3.4.13 | 08/10/2021 | configuration api - changed some field types form string to number | 
| 3.4.12 | 08/10/2021 | email engine - added webhook editor values for internal ui  | 
| 3.4.9 | 08/05/2021 | configuration api - updated annotations for method names | 
| 3.4.8 | 08/04/2021 | configuration api - payments config refactoring | 
| 3.4.7 | 08/04/2021 | esp folders for lists/segments | 
| 3.4.5 | 08/03/2021 | configuration api bug fix for a bad response object on updateRotatingTransactionGateway | 
| 3.4.3 | 08/03/2021 | package tracking - add event_iso_date and event_timezone_id | 
| 3.4.2 | 07/29/2021 | bug fixes for new configuration api | 
| 3.4.1 | 07/29/2021 | bug fixes for new configuration api | 
| 3.4.0 | 07/29/2021 | added new configuration api (not live yet. sdk only works against development presently) | 
| 3.3.2 | 07/16/2021 | sso bug fixes | 
| 3.3.1 | 07/16/2021 | screen recording - event sub text used for assisting in UX rendering | 
| 3.3.0 | 07/16/2021 | new endpoint SingleSignOn | 
| 3.2.15 | 07/13/2021 | storefront communications - added methods to retrieve step dispatch logs | 
| 3.2.14 | 07/12/2021 | fix documentation bug on packing slip methods for order api | 
| 3.2.13 | 07/12/2021 | coupon api - added hideFromCustomer flag | 
| 3.2.12 | 07/09/2021 | new fulfillment and order methods for generation of packing slips | 
| 3.2.11 | 07/08/2021 | screen recording - missing external tracking flag added | 
| 3.2.10 | 07/08/2021 | customer profile - allow drop shipping options | 
| 3.2.9 | 07/07/2021 | screen recording - provide cost per thousand and retention interval | 
| 3.2.8 | 07/06/2021 | intgeration logs - min max log date/time retured in filter values | 
| 3.2.7 | 07/05/2021 | integration logger bug fixes | 
| 3.2.6 | 06/25/2021 | integration log: added logger name | 
| 3.2.2 | 06/24/2021 | integration log file mime type added | 
| 3.2.0 | 06/23/2021 | Changed 4 methods due to naming conflicts revealed through swagger validator.  All internal methods, so impact should be negligible | 
| 3.1.50 | 06/23/2021 | Integrated Logging: returning back streamed files for log requests | 
| 3.1.49 | 06/17/2021 | Integrated Logging: standardize the response object from getIntegrationLog method  | 
| 3.1.47 | 06/16/2021 | Integrated Logging Rest API  | 
| 3.1.46 | 06/14/2021 | Screen recording: server side paginated heat map index with url contains filters, Item: channel partner item mapping unit cost override  | 
| 3.1.44 | 06/02/2021 | new boolean flag on items object to allow sharing of reviews between items   | 
| 3.1.43 | 06/01/2021 | fix item serialized name of item serialized name for channel partner item mappings  | 
| 3.1.42 | 06/01/2021 | added quickbooks accounting codes at the tiered level for tiered coupons  | 
| 3.1.41 | 05/21/2021 | screen recording heatmap methods | 
| 3.1.40 | 05/20/2021 | Order.summary.actual_payment_processing field added | 
| 3.1.39 | 05/19/2021 | full deployment to ensure all language SDKs are up to date | 
| 3.1.37 | 05/18/2021 | removed php sdk dependency on ext-mbstring by generating sdk with polyfill requirement.  sdk is more portable now. | 
| 3.1.35 | 05/14/2021 | screen recording histogram data  | 
| 3.1.34 | 05/12/2021 | screen recording preferred language, last x days filter, referrer domain | 
| 3.1.33 | 05/11/2021 | creen recording filter for affiliate id and email | 
| 3.1.32 | 05/06/2021 | customer profile pending loyalty points  | 
| 3.1.31 | 05/06/2021 | Added email domian field to screen recordings for filtering  | 
| 3.1.30 | 04/27/2021 | OrderApi.processPayment now allows a specific amount to be billed  | 
| 3.1.29 | 04/26/2021 | screen recording language iso code | 
| 3.1.28 | 04/26/2021 | screen recording statistics on the setting object | 
| 3.1.27 | 04/20/2021 | bug fix - annotation misspell on new email campaign property |
| 3.1.26 | 04/20/2021 | StoreFront Connumications - flag to end campaign or flow once purchase happens anywhere |
| 3.1.25 | 04/19/2021 | Screen recording UTM campaign and source fields |
| 3.1.24 | 04/16/2021 | Screen recording aggregations on communications campaign/flows |
| 3.1.22 | 04/09/2021 | Move URL filter values into page level view for screen recordings |
| 3.1.18 | 03/17/2021 | Added order query by ship on date |
| 3.1.17 | 03/17/2021 | New coupon - percent off MSRP item |
| 3.1.16 | 03/16/2021 | screen recording filter page parameter names |
| 3.1.15 | 03/15/2021 | fix response from deleteScreenRecordingSegment that should have been void |
| 3.1.14 | 03/15/2021 | sort screen recordings by favorite flag |
| 3.1.13 | 03/02/2021 | new webhook order_payment_failed |
| 3.1.12 | 02/25/2021 | added screen recording visitor_first_seen property |
| 3.1.11 | 02/24/2021 | Added Screen recording visitor number |
| 3.1.10 | 02/24/2021 | Added Screen recording merchant notes |
| 3.1.9 | 02/24/2021 | Allow coupons to be configured as unique with expiration on cart step within StoreFront Communications |
| 3.1.8 | 02/24/2021 | Add flag: screen recording missing event boolean |
| 3.1.5 | 02/12/2021 | Bug Fix: PHP retry logic missing a closing brace. Also screen recording page view data response refactor |
| 3.1.3 | 02/11/2021 | Bug Fix: wrong return type on CustomerApi.validateEmailVerificationToken |
| 3.1.2 | 02/11/2021 | CustomerApi.getEmailVerificationToken, CustomerApi.validateEmailVerificationToken added to allow for custom email verification.  Also added favorite flag to screen recording object |
| 3.1.1 | 02/10/2021 | CustomerApi.getCustomerByEmail() method added |
| 3.1.0 | 02/10/2021 | Minor revision jump.  Added new convenience methods for simple_key use to all api calls.  Updated docs |
| 3.0.75 | 02/01/2021 | StoreFront Communication plan revision (internal use) |
| 3.0.71 | 01/28/2021 | BugFix: PHP SDK retry logic NPE |
| 3.0.70 | 01/26/2021 | Checkout return URL support |
| 3.0.66 | 01/22/2021 | code library attributes (mostly internal dev) |
| 3.0.65 | 01/22/2021 | Added folder support for email campaigns and flows |
| 3.0.64 | 01/20/2021 | Bug fix on revenue per customer field incorrectly named. |
| 3.0.63 | 01/20/2021 | CouponAPI: bug fixes and new method doesCouponCodeExist |
| 3.0.62 | 01/19/2021 | Added retry ability when rate limit is triggered (PHP SDK only) only) Other sdk to follow. |
| 3.0.60 | 01/14/2021 | Working with Ruby SDK |
| 3.0.57 | 12/17/2020 | CouponAPI: Added Buy one get one free coupon |
| 3.0.53 | 12/14/2020 | StoreFrontAPI: added a duplicate method to load the pricing tiers on the StoreFront |
| 3.0.51 | 12/09/2020 | UserAPI: internal bug preventing proper usage of user group creation |
| 3.0.45 | 12/03/2020 | CouponAPI: added partial searches to getCoupon params, added deleteCoupons method, fixed bugs |
| 3.0.44 | 12/03/2020 | Code library updates, intended for internal use |
| 3.0.43 | 12/02/2020 | Added fields to code library to handle versions of published items |
| 3.0.42 | 12/02/2020 | Added display values to CouponApi.getEditorValues to make type dropdowns easy |
| 3.0.41 | 11/17/2020 | New modify cart step option for StoreFront communications |
| 3.0.39 | 11/12/2020 | Added Customer.tax_codes.taxjar_exemption_type |
| 3.0.38 | 11/09/2020 | Added TaxProviderTaxJar.configuration.send_outside_nexus flag |
| 3.0.37 | 11/06/2020 | Added transactional email screenshots for code library |
| 3.0.36 | 11/03/2020 | Added missing constant for pre-order stage |
| 3.0.34 | 10/26/2020 | UserAPI initial release |
| 3.0.33 | 10/23/2020 | Added library_item_oid to StoreFront Communications email object for upcoming code library |
| 3.0.32 | 10/21/2020 | Added new StoreFrontApi.search method that takes a POST instead of a GET |
| 3.0.31 | 10/16/2020 | more dev work on code library (internal) |
| 3.0.30 | 10/08/2020 | development work on code library (internal), first version of UserAPI.  The UserAPI is not live yet. |
| 3.0.29 | 09/29/2020 | new boolean field on coupon: bug fix |
| 3.0.28 | 09/29/2020 | new boolean field on coupon: free item with purchase of another item |
| 3.0.27 | 09/29/2020 | Refactored the code library applyToStoreFront to provide support for marketing emails |
| 3.0.26 | 09/25/2020 | Expose actual shipping and fulfillment costs in the order summary object |
| 3.0.25 | 09/16/2020 | New method: OrderApi.adjustOrderTotal |
| 3.0.24 | 09/10/2020 | Bugfix: incorrect response type on CheckoutAPI.registerAffiliateClick |
| 3.0.23 | 09/02/2020 | Added flag to email plan object.  allow_tracking_emails |
| 3.0.22 | 09/02/2020 | Order object - added tracking details |
| 3.0.21 | 09/01/2020 | break fix in php sdk due to bad namespace |
| 3.0.20 | 09/01/2020 | Added OrderApi.processPayment method |
| 3.0.19 | 08/28/2020 | Code Library development: added kraken parameters for thumbnail image generation. |
| 3.0.17 | 08/26/2020 | cont. development work on Code Library |
| 3.0.14 | 08/19/2020 | development work on Code Library |
| 3.0.13 | 08/18/2020 | development work on Code Library |
| 3.0.12 | 08/13/2020 | screenshot urls for campaigns and flows (storefront communications) |
| 3.0.11 | 08/12/2020 | Refactoring and development for Code Library (not released yet) |
| 3.0.10 | 08/10/2020 | Method for registering an affliate click via the SDK, found within CheckoutAPI |
| 3.0.8 | 08/05/2020 | stub for code library 'getLibraryFilterValues' for populating drop down lists |
| 3.0.4 | 08/05/2020 | fixed misspell of 'version' in LibraryItem object. |
| 3.0.3 | 08/04/2020 | added description to addToLibrary call to allow for initial description |
| 3.0.2 | 08/03/2020 | added option on email render step config to allow override of subject, added flow/campaign flag to end once customer purchases |
| 3.0.1 | 07/27/2020 | added init_json to storefront communication email objects |
| 3.0.0 | 07/01/2020 | upgraded our swagger-codegen fork to the latest swagger source code. this was a major changes so we jumped version numbers.  please test all code. |

Some changes jump version numbers due to multiple commits for bug fixes, omissions, and errors.
At UltraCart, we eat our own dog food, and we increment the version number for every commit in order
to generate a new javascript npm.  For this reason, version gaps will be found in the change log above.
